Class: Onlyfans::Models::AuthenticateStartParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::AuthenticateStartParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/authenticate_start_params.rb,
sig/onlyfans/models/authenticate_start_params.rbs
Overview
Defined Under Namespace
Modules: AuthType, ProxyCountry Classes: CustomProxy
Instance Attribute Summary collapse
-
#auth_id ⇒ String?
The auth_id from OnlyFans session cookies.
-
#auth_type ⇒ Symbol, ...
The authentication method to use.
-
#cookies ⇒ String?
The full cookie string (semicolon-separated).
-
#custom_proxy ⇒ Onlyfans::Models::AuthenticateStartParams::CustomProxy?
Custom proxy configuration.
-
#email ⇒ String?
The email address of the OnlyFans account.
-
#force_connect ⇒ Boolean?
Set to true to connect the account even if it already exists.
-
#name ⇒ String?
A display name for the account.
-
#password ⇒ String?
The password of the OnlyFans account.
-
#proxy_country ⇒ Symbol, ...
The country of the managed proxy server you want to use.
-
#user_agent ⇒ String?
The browser User-Agent string.
-
#xbc ⇒ String?
The X-BC token from request headers.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(host: nil, password: nil, port: nil, username: nil) ⇒ Object
constructor
Custom proxy configuration.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(host: nil, password: nil, port: nil, username: nil) ⇒ Object
Custom proxy configuration. Cannot be used together with proxyCountry.
|
|
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 86
|
Instance Attribute Details
#auth_id ⇒ String?
The auth_id from OnlyFans session cookies. Required when auth_type is
raw_data.
15 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 15 optional :auth_id, String |
#auth_type ⇒ Symbol, ...
The authentication method to use. Defaults to email_password if omitted. Use
mobile_app to authenticate via the FansAPI Auth+ mobile app (no credential
fields required).
23 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 23 optional :auth_type, enum: -> { Onlyfans::AuthenticateStartParams::AuthType } |
#cookies ⇒ String?
The full cookie string (semicolon-separated). Required when auth_type is
raw_data.
30 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 30 optional :cookies, String |
#custom_proxy ⇒ Onlyfans::Models::AuthenticateStartParams::CustomProxy?
Custom proxy configuration. Cannot be used together with proxyCountry.
36 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 36 optional :custom_proxy, -> { Onlyfans::AuthenticateStartParams::CustomProxy }, api_name: :customProxy |
#email ⇒ String?
The email address of the OnlyFans account. Required when auth_type is
email_password.
43 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 43 optional :email, String |
#force_connect ⇒ Boolean?
Set to true to connect the account even if it already exists
49 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 49 optional :force_connect, Onlyfans::Internal::Type::Boolean |
#name ⇒ String?
A display name for the account. If omitted, defaults to the email address or auth_id.
56 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 56 optional :name, String |
#password ⇒ String?
The password of the OnlyFans account. Required when auth_type is
email_password.
63 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 63 optional :password, String |
#proxy_country ⇒ Symbol, ...
The country of the managed proxy server you want to use. Eg. "us" for United States. Cannot be used together with customProxy.
70 71 72 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 70 optional :proxy_country, enum: -> { Onlyfans::AuthenticateStartParams::ProxyCountry }, api_name: :proxyCountry |
#user_agent ⇒ String?
The browser User-Agent string. Required when auth_type is raw_data.
78 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 78 optional :user_agent, String |
#xbc ⇒ String?
The X-BC token from request headers. Required when auth_type is raw_data.
84 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 84 optional :xbc, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 124
|
Instance Method Details
#to_hash ⇒ {
88 |
# File 'sig/onlyfans/models/authenticate_start_params.rbs', line 88
def to_hash: -> {
|