Class: Onlyfans::Models::AuthenticateStartResponse::UnionMember1
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::AuthenticateStartResponse::UnionMember1
- Defined in:
- lib/onlyfans/models/authenticate_start_response.rb
Instance Attribute Summary collapse
- #attempt_id ⇒ String?
- #message ⇒ String?
- #mobile_auth_session_deeplink ⇒ String?
- #polling_url ⇒ String?
Instance Method Summary collapse
-
#initialize(attempt_id: nil, message: nil, mobile_auth_session_deeplink: nil, polling_url: nil) ⇒ Object
constructor
For mobile_app auth type — includes the session code to scan with the FansAPI Auth+ app.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attempt_id: nil, message: nil, mobile_auth_session_deeplink: nil, polling_url: nil) ⇒ Object
For mobile_app auth type — includes the session code to scan with the FansAPI Auth+ app
|
|
# File 'lib/onlyfans/models/authenticate_start_response.rb', line 62
|
Instance Attribute Details
#attempt_id ⇒ String?
45 |
# File 'lib/onlyfans/models/authenticate_start_response.rb', line 45 optional :attempt_id, String |
#message ⇒ String?
50 |
# File 'lib/onlyfans/models/authenticate_start_response.rb', line 50 optional :message, String |
#mobile_auth_session_deeplink ⇒ String?
55 |
# File 'lib/onlyfans/models/authenticate_start_response.rb', line 55 optional :mobile_auth_session_deeplink, String |
#polling_url ⇒ String?
60 |
# File 'lib/onlyfans/models/authenticate_start_response.rb', line 60 optional :polling_url, String |