Class: Onlyfans::Models::Chats::MessageSendParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::Chats::MessageSendParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/chats/message_send_params.rb,
sig/onlyfans/models/chats/message_send_params.rbs
Overview
Instance Attribute Summary collapse
- #account ⇒ String
- #chat_id ⇒ String
-
#giphy_id ⇒ String?
The ID of the Giphy GIF to attach to the message.
-
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden.
-
#media_files ⇒ Array<Object>?
Direct file uploads, OFAPI
ofapi_media_IDs, or OF vault IDs. -
#previews ⇒ Array<Object>?
Direct file uploads, OFAPI
ofapi_media_IDs, OF vault IDs, or integer indices referencing uploaded files inmediaFiles. -
#price ⇒ Integer?
Price for paid content (0 or between 3-200).
-
#reply_to_message_id ⇒ Integer?
Mark this message as a reply to another (can be either your own, or the recipient's).
-
#rf_guest ⇒ String?
Array of OnlyFans Release Form Guest IDs to tag in your message.
-
#rf_partner ⇒ String?
Array of OnlyFans Release Form Partners IDs to tag in your message.
-
#rf_tag ⇒ String?
Array of OnlyFans Creator User IDs to tag in your message.
-
#text ⇒ String?
The message text content.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, chat_id:, giphy_id: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, reply_to_message_id: nil, rf_guest: nil, rf_partner: nil, rf_tag: nil, text: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageSendParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, chat_id:, giphy_id: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, reply_to_message_id: nil, rf_guest: nil, rf_partner: nil, rf_tag: nil, text: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::Chats::MessageSendParams for more details.
**mediaFi
|
|
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 89
|
Instance Attribute Details
#account ⇒ String
14 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 14 required :account, String |
#chat_id ⇒ String
19 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 19 required :chat_id, String |
#giphy_id ⇒ String?
The ID of the Giphy GIF to attach to the message. Get IDs from the Giphy listing
endpoints (/giphy/trending, /giphy/search).
26 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 26 optional :giphy_id, String, api_name: :giphyId |
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden
32 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 32 optional :locked_text, Onlyfans::Internal::Type::Boolean, api_name: :lockedText |
#media_files ⇒ Array<Object>?
Direct file uploads, OFAPI ofapi_media_ IDs, or OF vault IDs. Will be hidden
if price is provided.
39 40 41 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 39 optional :media_files, Onlyfans::Internal::Type::ArrayOf[Onlyfans::Internal::Type::Unknown], api_name: :mediaFiles |
#previews ⇒ Array<Object>?
Direct file uploads, OFAPI ofapi_media_ IDs, OF vault IDs, or integer indices
referencing uploaded files in mediaFiles. Will be shown if price is
provided.
49 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 49 optional :previews, Onlyfans::Internal::Type::ArrayOf[Onlyfans::Internal::Type::Unknown] |
#price ⇒ Integer?
Price for paid content (0 or between 3-200). In case this is not zero, mediaFiles is required
56 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 56 optional :price, Integer |
#reply_to_message_id ⇒ Integer?
Mark this message as a reply to another (can be either your own, or the recipient's)
63 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 63 optional :reply_to_message_id, Integer, api_name: :replyToMessageId |
#rf_guest ⇒ String?
Array of OnlyFans Release Form Guest IDs to tag in your message
69 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 69 optional :rf_guest, String, api_name: :rfGuest |
#rf_partner ⇒ String?
Array of OnlyFans Release Form Partners IDs to tag in your message
75 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 75 optional :rf_partner, String, api_name: :rfPartner |
#rf_tag ⇒ String?
Array of OnlyFans Creator User IDs to tag in your message
81 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 81 optional :rf_tag, String, api_name: :rfTag |
#text ⇒ String?
The message text content. Required unless a media file is present.
87 |
# File 'lib/onlyfans/models/chats/message_send_params.rb', line 87 optional :text, String |
Instance Method Details
#to_hash ⇒ {
85 |
# File 'sig/onlyfans/models/chats/message_send_params.rbs', line 85
def to_hash: -> {
|