Class: Onlyfans::Models::ClientSessionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::ClientSessionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/client_session_create_params.rb,
sig/onlyfans/models/client_session_create_params.rbs
Overview
Defined Under Namespace
Modules: ProxyCountry
Instance Attribute Summary collapse
-
#client_reference_id ⇒ String?
Your Internal Reference ID for the connected account.
-
#display_name ⇒ String
Display Name of the account visible in your OnlyFansAPI Console Dashboard.
- #proxy_country ⇒ Symbol, ...
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
23 |
# File 'sig/onlyfans/models/client_session_create_params.rbs', line 23
def initialize: (
|
Instance Attribute Details
#client_reference_id ⇒ String?
Your Internal Reference ID for the connected account.
20 |
# File 'lib/onlyfans/models/client_session_create_params.rb', line 20 optional :client_reference_id, String |
#display_name ⇒ String
Display Name of the account visible in your OnlyFansAPI Console Dashboard.
14 |
# File 'lib/onlyfans/models/client_session_create_params.rb', line 14 required :display_name, String |
#proxy_country ⇒ Symbol, ...
25 |
# File 'lib/onlyfans/models/client_session_create_params.rb', line 25 optional :proxy_country, enum: -> { Onlyfans::ClientSessionCreateParams::ProxyCountry }, nil?: true |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/onlyfans/models/client_session_create_params.rbs', line 30
def to_hash: -> {
|