Class: Onlyfans::Models::MassMessagingRetrieveOverviewParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/mass_messaging_retrieve_overview_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, end_date: nil, limit: nil, query: nil, start_date: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::MassMessagingRetrieveOverviewParams for more details.

Parameters:

  • account (String)
  • end_date (String) (defaults to: nil)

    The latest mass message to retrieve. Keep empty to get all. MUST BE DATE AFTER ‘

  • limit (Integer) (defaults to: nil)

    Number of mass messages to return (default = 10)

  • query (String) (defaults to: nil)

    Optionally, find a mass message by the message text.

  • start_date (String) (defaults to: nil)

    The earliest mass message to retrieve. Keep empty to get all.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/mass_messaging_retrieve_overview_params.rb', line 40

Instance Attribute Details

#accountString

Returns:

  • (String)


13
# File 'lib/onlyfans/models/mass_messaging_retrieve_overview_params.rb', line 13

required :account, String

#end_dateString?

The latest mass message to retrieve. Keep empty to get all. MUST BE DATE AFTER ‘startDate`. This is also used for pagination.

Returns:

  • (String, nil)


20
# File 'lib/onlyfans/models/mass_messaging_retrieve_overview_params.rb', line 20

optional :end_date, String

#limitInteger?

Number of mass messages to return (default = 10)

Returns:

  • (Integer, nil)


26
# File 'lib/onlyfans/models/mass_messaging_retrieve_overview_params.rb', line 26

optional :limit, Integer

#queryString?

Optionally, find a mass message by the message text.

Returns:

  • (String, nil)


32
# File 'lib/onlyfans/models/mass_messaging_retrieve_overview_params.rb', line 32

optional :query, String

#start_dateString?

The earliest mass message to retrieve. Keep empty to get all.

Returns:

  • (String, nil)


38
# File 'lib/onlyfans/models/mass_messaging_retrieve_overview_params.rb', line 38

optional :start_date, String