Class: Onlyfans::Models::MassMessagingUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/mass_messaging_update_params.rb,
sig/onlyfans/models/mass_messaging_update_params.rbs

Overview

See Also:

  • Onlyfans::Resources::MassMessaging#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, id:, text:, giphy_id: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, scheduled_date: nil, user_ids: nil, user_lists: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::MassMessagingUpdateParams for more details.

**mediaFi

Parameters:

  • account (String)
  • id (String)
  • text (String) —

    The message text content

  • giphy_id (String) (defaults to: nil) —

    The ID of the Giphy GIF to attach to the message. Get IDs from the Giphy listing

  • locked_text (Boolean) (defaults to: nil) —

    Whether the text should be shown or hidden

  • media_files (Array<String>) (defaults to: nil) —

    Array of media file upload prefixed_ids, or OF media IDs (required if price is n

  • previews (Array<String>) (defaults to: nil) —

    Array of media file upload prefixed_ids, or OF media IDs (required if price is n

  • price (Integer) (defaults to: nil) —

    Price for paid content (0 or between 3-200). In case this is not zero,

  • scheduled_date (String) (defaults to: nil) —

    Schedule the chat message in the future (UTC timezone).

  • user_ids (Array<String>) (defaults to: nil) —

    Array of user IDs that the mass message will be sent to.

  • user_lists (Array<String>) (defaults to: nil) —

    Array of user list IDs that the mass message will be sent to.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 79

Instance Attribute Details

#account ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 13

required :account, String

#giphy_id ⇒ String?

The ID of the Giphy GIF to attach to the message. Get IDs from the Giphy listing endpoints (/giphy/trending, /giphy/search).

Parameters:

  • (String)

Returns:

  • (String, nil)


31
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 31

optional :giphy_id, String, api_name: :giphyId

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 18

required :id, String

#locked_text ⇒ Boolean?

Whether the text should be shown or hidden

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


37
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 37

optional :locked_text, Onlyfans::Internal::Type::Boolean, api_name: :lockedText

#media_files ⇒ Array<String>?

Array of media file upload prefixed_ids, or OF media IDs (required if price is not 0). Will be hidden if price is provided.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


44
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 44

optional :media_files, Onlyfans::Internal::Type::ArrayOf[String], api_name: :mediaFiles

#previews ⇒ Array<String>?

Array of media file upload prefixed_ids, or OF media IDs (required if price is not 0). Will be shown if price is provided. All previews values must also exist in the mediaFiles array.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


52
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 52

optional :previews, Onlyfans::Internal::Type::ArrayOf[String]

#price ⇒ Integer?

Price for paid content (0 or between 3-200). In case this is not zero, mediaFiles is required

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


59
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 59

optional :price, Integer

#scheduled_date ⇒ String?

Schedule the chat message in the future (UTC timezone).

Parameters:

  • (String)

Returns:

  • (String, nil)


65
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 65

optional :scheduled_date, String, api_name: :scheduledDate

#text ⇒ String

The message text content

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 24

required :text, String

#user_ids ⇒ Array<String>?

Array of user IDs that the mass message will be sent to.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


71
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 71

optional :user_ids, Onlyfans::Internal::Type::ArrayOf[String], api_name: :userIds

#user_lists ⇒ Array<String>?

Array of user list IDs that the mass message will be sent to.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


77
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 77

optional :user_lists, Onlyfans::Internal::Type::ArrayOf[String], api_name: :userLists

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


76
# File 'sig/onlyfans/models/mass_messaging_update_params.rbs', line 76

def to_hash: -> {