Class: Onlyfans::Models::Media::VaultListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/media/vault_list_params.rb,
sig/onlyfans/models/media/vault_list_params.rbs

Overview

See Also:

  • Onlyfans::Resources::Media::Vault#list

Defined Under Namespace

Modules: Field, Sort, Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, field: nil, limit: nil, list: nil, offset: nil, query: nil, sort: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::Media::VaultListParams for more details.

Vaul

Parameters:

  • account (String)
  • field (Symbol, Onlyfans::Models::Media::VaultListParams::Field) (defaults to: nil) —

    Sort the results by a field. Default recent

  • limit (Integer) (defaults to: nil) —

    Number of media to return per page (10 - 100). Default: 24

  • list (Integer) (defaults to: nil) —

    Only show media items from a specific list (category). **Refer to our Media

  • offset (Integer) (defaults to: nil) —

    The offset used for pagination. Default 0

  • query (String, nil) (defaults to: nil) —

    Optionally, search for a text query.

  • sort (Symbol, Onlyfans::Models::Media::VaultListParams::Sort) (defaults to: nil) —

    Sort the results. Default desc

  • type (Symbol, Onlyfans::Models::Media::VaultListParams::Type) (defaults to: nil) —

    Filter the results by a media type. Keep empty to show all media.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/media/vault_list_params.rb', line 59

Instance Attribute Details

#account ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 14

required :account, String

#field ⇒ Symbol, ...

Sort the results by a field. Default recent



20
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 20

optional :field, enum: -> { Onlyfans::Media::VaultListParams::Field }

#limit ⇒ Integer?

Number of media to return per page (10 - 100). Default: 24

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 26

optional :limit, Integer

#list ⇒ Integer?

Only show media items from a specific list (category). Refer to our Media Vault Lists endpoints.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


33
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 33

optional :list, Integer

#offset ⇒ Integer?

The offset used for pagination. Default 0

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


39
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 39

optional :offset, Integer

#query ⇒ String?

Optionally, search for a text query.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


45
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 45

optional :query, String, nil?: true

#sort ⇒ Symbol, ...

Sort the results. Default desc



51
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 51

optional :sort, enum: -> { Onlyfans::Media::VaultListParams::Sort }

#type ⇒ Symbol, ...

Filter the results by a media type. Keep empty to show all media.



57
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 57

optional :type, enum: -> { Onlyfans::Media::VaultListParams::Type }

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/onlyfans/models/media/vault_list_params.rb', line 90

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


67
# File 'sig/onlyfans/models/media/vault_list_params.rbs', line 67

def to_hash: -> {