Class: Onlyfans::Models::MediaUploadParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::MediaUploadParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/media_upload_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #account ⇒ String
-
#async ⇒ Boolean?
Set to ‘true` to process uploads in the background.
-
#file ⇒ Pathname, ...
The file to upload.
-
#file_url ⇒ String?
A URL to download the file from.
-
#type ⇒ Symbol, ...
Set to ‘avatar` if this file will be used as a profile picture, `header` for a profile banner, or keep empty if this file will be for anything else.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, async: nil, file: nil, file_url: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MediaUploadParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, async: nil, file: nil, file_url: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::MediaUploadParams for more details.
|
|
# File 'lib/onlyfans/models/media_upload_params.rb', line 43
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/media_upload_params.rb', line 13 required :account, String |
#async ⇒ Boolean?
Set to ‘true` to process uploads in the background. Returns a `polling_url` to check status. Recommended for large files.
20 |
# File 'lib/onlyfans/models/media_upload_params.rb', line 20 optional :async, Onlyfans::Internal::Type::Boolean |
#file ⇒ Pathname, ...
The file to upload. Required if ‘file_url` is not provided. Maximum file size: 100 MB (limited by Cloudflare).
27 |
# File 'lib/onlyfans/models/media_upload_params.rb', line 27 optional :file, Onlyfans::Internal::Type::FileInput |
#file_url ⇒ String?
A URL to download the file from. Required if ‘file` is not provided. Maximum file size depends on the subscription configuration.
34 |
# File 'lib/onlyfans/models/media_upload_params.rb', line 34 optional :file_url, String |
#type ⇒ Symbol, ...
Set to ‘avatar` if this file will be used as a profile picture, `header` for a profile banner, or keep empty if this file will be for anything else.
41 |
# File 'lib/onlyfans/models/media_upload_params.rb', line 41 optional :type, enum: -> { Onlyfans::MediaUploadParams::Type } |