Class: Onlyfans::Models::PostArchiveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/post_archive_params.rb,
sig/onlyfans/models/post_archive_params.rbs

Overview

See Also:

  • Onlyfans::Resources::Posts#archive

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, post_id:, private_archive: nil, request_options: {}) ⇒ Object

Parameters:

  • (defaults to: nil)

    Set to true to move this post to the Private Archive.

  • (defaults to: {})


# File 'lib/onlyfans/models/post_archive_params.rb', line 26

Instance Attribute Details

#account ⇒ String

Parameters:

Returns:



13
# File 'lib/onlyfans/models/post_archive_params.rb', line 13

required :account, String

#post_id ⇒ Integer

Parameters:

Returns:



18
# File 'lib/onlyfans/models/post_archive_params.rb', line 18

required :post_id, Integer

#private_archive ⇒ Boolean?

Set to true to move this post to the Private Archive.

Parameters:

Returns:



24
# File 'lib/onlyfans/models/post_archive_params.rb', line 24

optional :private_archive, Onlyfans::Internal::Type::Boolean

Instance Method Details

#to_hash ⇒ {

Returns:



26
# File 'sig/onlyfans/models/post_archive_params.rbs', line 26

def to_hash: -> {