Class: Onlyfans::Models::PostListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/post_list_params.rb

Overview

Defined Under Namespace

Modules: Order, Sort

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, counters: nil, limit: nil, minimum_publish_date: nil, offset: nil, order: nil, pinned: nil, query: nil, sort: nil, request_options: {}) ⇒ Object

Parameters:

  • account (String)
  • counters (Boolean) (defaults to: nil)

    Set to true to include an array of counters (see example responses)

  • limit (Integer) (defaults to: nil)

    Number of posts to return (default = 10)

  • minimum_publish_date (String) (defaults to: nil)

    Filter posts by minimum publish date

  • offset (Integer) (defaults to: nil)

    Number of posts to skip for pagination

  • order (Symbol, Onlyfans::Models::PostListParams::Order) (defaults to: nil)

    Order the returned posts (default = publish_date)

  • pinned (Boolean) (defaults to: nil)

    Set to true to only show pinned posts

  • query (String) (defaults to: nil)

    Search query to filter posts

  • sort (Symbol, Onlyfans::Models::PostListParams::Sort) (defaults to: nil)

    Sort the returned posts (default = desc)

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/post_list_params.rb', line 63

Instance Attribute Details

#accountString

Returns:

  • (String)


13
# File 'lib/onlyfans/models/post_list_params.rb', line 13

required :account, String

#countersBoolean?

Set to true to include an array of counters (see example responses)

Returns:

  • (Boolean, nil)


19
# File 'lib/onlyfans/models/post_list_params.rb', line 19

optional :counters, Onlyfans::Internal::Type::Boolean

#limitInteger?

Number of posts to return (default = 10)

Returns:

  • (Integer, nil)


25
# File 'lib/onlyfans/models/post_list_params.rb', line 25

optional :limit, Integer

#minimum_publish_dateString?

Filter posts by minimum publish date

Returns:

  • (String, nil)


31
# File 'lib/onlyfans/models/post_list_params.rb', line 31

optional :minimum_publish_date, String

#offsetInteger?

Number of posts to skip for pagination

Returns:

  • (Integer, nil)


37
# File 'lib/onlyfans/models/post_list_params.rb', line 37

optional :offset, Integer

#orderSymbol, ...

Order the returned posts (default = publish_date)

Returns:



43
# File 'lib/onlyfans/models/post_list_params.rb', line 43

optional :order, enum: -> { Onlyfans::PostListParams::Order }

#pinnedBoolean?

Set to true to only show pinned posts

Returns:

  • (Boolean, nil)


49
# File 'lib/onlyfans/models/post_list_params.rb', line 49

optional :pinned, Onlyfans::Internal::Type::Boolean

#queryString?

Search query to filter posts

Returns:

  • (String, nil)


55
# File 'lib/onlyfans/models/post_list_params.rb', line 55

optional :query, String

#sortSymbol, ...

Sort the returned posts (default = desc)

Returns:



61
# File 'lib/onlyfans/models/post_list_params.rb', line 61

optional :sort, enum: -> { Onlyfans::PostListParams::Sort }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/onlyfans/models/post_list_params.rb', line 92