Class: Onlyfans::Models::PostUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/post_update_params.rb

Overview

Defined Under Namespace

Modules: VotingType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, post_id:, text:, expire_days: nil, fund_raising_target_amount: nil, fund_raising_tips_presets: nil, label_ids: nil, media_files: nil, price: nil, rf_tag: nil, save_for_later: nil, scheduled_date: nil, voting_correct_index: nil, voting_due: nil, voting_options: nil, voting_type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::PostUpdateParams for more details.

**mediaFi

Parameters:

  • account (String)
  • post_id (Integer)
  • text (String)

    The post text content

  • expire_days (Integer) (defaults to: nil)

    Number of days after which the post will expire. Between 1 and 30 days. Keep emp

  • fund_raising_target_amount (Integer) (defaults to: nil)

    Add a fundraising target to your post. If present, value must be at least 10.

  • fund_raising_tips_presets (Array<String>) (defaults to: nil)

    Specify which tip amounts will be listed under the fundraising card. Required wi

  • label_ids (String) (defaults to: nil)

    Array of OF label IDs. Refer to our ‘/posts/labels` endpoint.

  • media_files (String) (defaults to: nil)

    Array of OFAPI ‘ofapi_media_` IDs, or OF media IDs

  • price (Integer) (defaults to: nil)

    Price for paid content (0 or between 3-100). In case this is not zero,

  • rf_tag (String) (defaults to: nil)

    Array OnlyFans creator user IDs to tag in your post

  • save_for_later (Boolean) (defaults to: nil)

    Add your post to the “Saved for later” queue.

  • scheduled_date (String) (defaults to: nil)

    Schedule your post in the future (UTC timezone).

  • voting_correct_index (Integer) (defaults to: nil)

    The array key of your quiz’ correct answer. Required when ‘votingType` is “quiz”

  • voting_due (Integer) (defaults to: nil)

    The due date (in days) of your poll/quiz. Can be 1, 3, 7 or 30 days. Can only be

  • voting_options (Array<String>) (defaults to: nil)

    The options of your poll/quiz. Required with ‘votingType`.

  • voting_type (Symbol, Onlyfans::Models::PostUpdateParams::VotingType) (defaults to: nil)

    Include a poll or quiz within your post.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/post_update_params.rb', line 112

Instance Attribute Details

#accountString

Returns:

  • (String)


13
# File 'lib/onlyfans/models/post_update_params.rb', line 13

required :account, String

#expire_daysInteger?

Number of days after which the post will expire. Between 1 and 30 days. Keep empty for no expiration.

Returns:

  • (Integer, nil)


31
# File 'lib/onlyfans/models/post_update_params.rb', line 31

optional :expire_days, Integer, api_name: :expireDays

#fund_raising_target_amountInteger?

Add a fundraising target to your post. If present, value must be at least 10.

Returns:

  • (Integer, nil)


37
# File 'lib/onlyfans/models/post_update_params.rb', line 37

optional :fund_raising_target_amount, Integer, api_name: :fundRaisingTargetAmount

#fund_raising_tips_presetsArray<String>?

Specify which tip amounts will be listed under the fundraising card. Required with ‘fundRaisingTargetAmount`, and you must provide at least 1 option. Array items cannot be higher than the `fundRaisingTargetAmount`.

Returns:

  • (Array<String>, nil)


45
46
47
# File 'lib/onlyfans/models/post_update_params.rb', line 45

optional :fund_raising_tips_presets,
Onlyfans::Internal::Type::ArrayOf[String],
api_name: :fundRaisingTipsPresets

#label_idsString?

Array of OF label IDs. Refer to our ‘/posts/labels` endpoint.

Returns:

  • (String, nil)


53
# File 'lib/onlyfans/models/post_update_params.rb', line 53

optional :label_ids, String, api_name: :labelIds

#media_filesString?

Array of OFAPI ‘ofapi_media_` IDs, or OF media IDs

Returns:

  • (String, nil)


59
# File 'lib/onlyfans/models/post_update_params.rb', line 59

optional :media_files, String, api_name: :mediaFiles

#post_idInteger

Returns:

  • (Integer)


18
# File 'lib/onlyfans/models/post_update_params.rb', line 18

required :post_id, Integer

#priceInteger?

Price for paid content (0 or between 3-100). In case this is not zero, mediaFiles is required

Returns:

  • (Integer, nil)


66
# File 'lib/onlyfans/models/post_update_params.rb', line 66

optional :price, Integer

#rf_tagString?

Array OnlyFans creator user IDs to tag in your post

Returns:

  • (String, nil)


72
# File 'lib/onlyfans/models/post_update_params.rb', line 72

optional :rf_tag, String, api_name: :rfTag

#save_for_laterBoolean?

Add your post to the “Saved for later” queue.

Returns:

  • (Boolean, nil)


78
# File 'lib/onlyfans/models/post_update_params.rb', line 78

optional :save_for_later, Onlyfans::Internal::Type::Boolean, api_name: :saveForLater

#scheduled_dateString?

Schedule your post in the future (UTC timezone).

Returns:

  • (String, nil)


84
# File 'lib/onlyfans/models/post_update_params.rb', line 84

optional :scheduled_date, String, api_name: :scheduledDate

#textString

The post text content

Returns:

  • (String)


24
# File 'lib/onlyfans/models/post_update_params.rb', line 24

required :text, String

#voting_correct_indexInteger?

The array key of your quiz’ correct answer. Required when ‘votingType` is “quiz”. Keep in mind that arrays start at `0`

Returns:

  • (Integer, nil)


91
# File 'lib/onlyfans/models/post_update_params.rb', line 91

optional :voting_correct_index, Integer, api_name: :votingCorrectIndex

#voting_dueInteger?

The due date (in days) of your poll/quiz. Can be 1, 3, 7 or 30 days. Can only be filled with ‘votingType`.

Returns:

  • (Integer, nil)


98
# File 'lib/onlyfans/models/post_update_params.rb', line 98

optional :voting_due, Integer, api_name: :votingDue

#voting_optionsArray<String>?

The options of your poll/quiz. Required with ‘votingType`.

Returns:

  • (Array<String>, nil)


104
# File 'lib/onlyfans/models/post_update_params.rb', line 104

optional :voting_options, Onlyfans::Internal::Type::ArrayOf[String], api_name: :votingOptions

#voting_typeSymbol, ...

Include a poll or quiz within your post.



110
# File 'lib/onlyfans/models/post_update_params.rb', line 110

optional :voting_type, enum: -> { Onlyfans::PostUpdateParams::VotingType }, api_name: :votingType