Class: Onlyfans::Models::SearchProfilesParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/search_profiles_params.rb,
sig/onlyfans/models/search_profiles_params.rbs

Overview

See Also:

  • Onlyfans::Resources::Search#profiles

Defined Under Namespace

Modules: Sort, SortDirection Classes: Filter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



76
# File 'sig/onlyfans/models/search_profiles_params.rbs', line 76

def initialize: (

Instance Attribute Details

#cursor ⇒ String?

Cursor for pagination. Use the next_cursor from the previous response to get the next page of results.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


15
# File 'lib/onlyfans/models/search_profiles_params.rb', line 15

optional :cursor, String, nil?: true

#filter ⇒ Onlyfans::Models::SearchProfilesParams::Filter?



20
# File 'lib/onlyfans/models/search_profiles_params.rb', line 20

optional :filter, -> { Onlyfans::SearchProfilesParams::Filter }

#instagram ⇒ String?

Filter by Instagram username.

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/onlyfans/models/search_profiles_params.rb', line 26

optional :instagram, String

#limit ⇒ Integer?

The number of profiles to return. For each returned profile we charge your account 1 credit. Default: 10. Must be at least 1. Must not be greater than 100.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


34
# File 'lib/onlyfans/models/search_profiles_params.rb', line 34

optional :limit, Integer

#location ⇒ String?

Filter by location.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/onlyfans/models/search_profiles_params.rb', line 40

optional :location, String

#max_subscribe_price ⇒ Float?

Filter by maximum subscribe price. Must be at least 0.00.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


46
# File 'lib/onlyfans/models/search_profiles_params.rb', line 46

optional :max_subscribe_price, Float

#min_subscribe_price ⇒ Float?

Filter by minimum subscribe price. Must be at least 0.00.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


52
# File 'lib/onlyfans/models/search_profiles_params.rb', line 52

optional :min_subscribe_price, Float

#query ⇒ String?

Query for full text search in username, display name, bio. Must be at least 3 characters.

Parameters:

  • (String)

Returns:

  • (String, nil)


59
# File 'lib/onlyfans/models/search_profiles_params.rb', line 59

optional :query, String

#sort ⇒ Symbol, ...

Field to sort by. ⭐️ Only available on the Pro and Enterprise plan.



65
# File 'lib/onlyfans/models/search_profiles_params.rb', line 65

optional :sort, enum: -> { Onlyfans::SearchProfilesParams::Sort }

#sort_direction ⇒ Symbol, ...

Direction for sorting. desc - highest value first. asc - lowest value first.



71
# File 'lib/onlyfans/models/search_profiles_params.rb', line 71

optional :sort_direction, enum: -> { Onlyfans::SearchProfilesParams::SortDirection }

#tiktok ⇒ String?

Filter by TikTok username.

Parameters:

  • (String)

Returns:

  • (String, nil)


77
# File 'lib/onlyfans/models/search_profiles_params.rb', line 77

optional :tiktok, String

#website ⇒ String?

Filter by website.

Parameters:

  • (String)

Returns:

  • (String, nil)


83
# File 'lib/onlyfans/models/search_profiles_params.rb', line 83

optional :website, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/onlyfans/models/search_profiles_params.rb', line 145


Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


92
# File 'sig/onlyfans/models/search_profiles_params.rbs', line 92

def to_hash: -> {