Class: Onlyfans::Models::SettingUpdateProfileParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/setting_update_profile_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, about: nil, avatar: nil, header: nil, location: nil, name: nil, username: nil, website: nil, wishlist: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::SettingUpdateProfileParams for more details.

Parameters:

  • account (String)
  • about (String, nil) (defaults to: nil)

    The new bio to use. Set to ‘null` to empty it.

  • avatar (String) (defaults to: nil)

    The new avatar to use. Must be a ‘ofapi_media_` ID. Refer to our `/media/upload`

  • header (String) (defaults to: nil)

    The new header (banner) to use. Must be a ‘ofapi_media_` ID. Refer to our `/medi

  • location (String, nil) (defaults to: nil)

    The new location to use. Set to ‘null` to empty it.

  • name (String, nil) (defaults to: nil)

    The new display name to use. Set to ‘null` to use the default display name.

  • username (String) (defaults to: nil)

    The new username to use. Make sure to first check if it exists using our ‘/setti

  • website (String, nil) (defaults to: nil)

    The new website URL to use. Must be a valid URL. Set to ‘null` to empty it.

  • wishlist (String, nil) (defaults to: nil)

    The new Amazon Wishlist URL to use. Must be a valid URL. Set to ‘null` to empty

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 67

Instance Attribute Details

#aboutString?

The new bio to use. Set to ‘null` to empty it.

Returns:

  • (String, nil)


19
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 19

optional :about, String, nil?: true

#accountString

Returns:

  • (String)


13
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 13

required :account, String

#avatarString?

The new avatar to use. Must be a ‘ofapi_media_` ID. Refer to our `/media/upload` endpoint on how to get this.

Returns:

  • (String, nil)


26
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 26

optional :avatar, String

#headerString?

The new header (banner) to use. Must be a ‘ofapi_media_` ID. Refer to our `/media/upload` endpoint on how to get this.

Returns:

  • (String, nil)


33
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 33

optional :header, String

#locationString?

The new location to use. Set to ‘null` to empty it.

Returns:

  • (String, nil)


39
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 39

optional :location, String, nil?: true

#nameString?

The new display name to use. Set to ‘null` to use the default display name.

Returns:

  • (String, nil)


45
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 45

optional :name, String, nil?: true

#usernameString?

The new username to use. Make sure to first check if it exists using our ‘/settings/username-exists` endpoint.

Returns:

  • (String, nil)


52
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 52

optional :username, String

#websiteString?

The new website URL to use. Must be a valid URL. Set to ‘null` to empty it.

Returns:

  • (String, nil)


58
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 58

optional :website, String, nil?: true

#wishlistString?

The new Amazon Wishlist URL to use. Must be a valid URL. Set to ‘null` to empty it.

Returns:

  • (String, nil)


65
# File 'lib/onlyfans/models/setting_update_profile_params.rb', line 65

optional :wishlist, String, nil?: true