Class: Onlyfans::Models::Settings::WelcomeMessageUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::Settings::WelcomeMessageUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/settings/welcome_message_update_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
- #is_forward ⇒ Boolean?
-
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden.
-
#media_files ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, or OF vault IDs.
-
#previews ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, OF vault IDs, or integer indices referencing uploaded files in `mediaFiles`.
-
#price ⇒ Integer?
Price for paid content (0 or between 3-200).
-
#rf_guest ⇒ String?
Array of OnlyFans Release Form Guest IDs to tag in your message.
-
#rf_partner ⇒ String?
Array of OnlyFans Release Form Partners IDs to tag in your message.
-
#rf_tag ⇒ String?
Array of OnlyFans Creator User IDs to tag in your message.
-
#text ⇒ String?
The welcome message text content.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, is_forward: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, rf_guest: nil, rf_partner: nil, rf_tag: nil, text: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WelcomeMessageUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, is_forward: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, rf_guest: nil, rf_partner: nil, rf_tag: nil, text: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::Settings::WelcomeMessageUpdateParams for more details.
**mediaFi
|
|
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 75
|
Instance Attribute Details
#account ⇒ String
14 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 14 required :account, String |
#is_forward ⇒ Boolean?
19 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 19 optional :is_forward, Onlyfans::Internal::Type::Boolean, api_name: :isForward |
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden.
25 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 25 optional :locked_text, Onlyfans::Internal::Type::Boolean, api_name: :lockedText |
#media_files ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, or OF vault IDs. Will be hidden if `price` is provided.
32 33 34 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 32 optional :media_files, Onlyfans::Internal::Type::ArrayOf[Onlyfans::Internal::Type::Unknown], api_name: :mediaFiles |
#previews ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, OF vault IDs, or integer indices referencing uploaded files in `mediaFiles`. Will be shown if `price` is provided.
42 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 42 optional :previews, Onlyfans::Internal::Type::ArrayOf[Onlyfans::Internal::Type::Unknown] |
#price ⇒ Integer?
Price for paid content (0 or between 3-200). In case this is not zero, mediaFiles is required.
49 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 49 optional :price, Integer |
#rf_guest ⇒ String?
Array of OnlyFans Release Form Guest IDs to tag in your message.
55 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 55 optional :rf_guest, String, api_name: :rfGuest |
#rf_partner ⇒ String?
Array of OnlyFans Release Form Partners IDs to tag in your message.
61 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 61 optional :rf_partner, String, api_name: :rfPartner |
#rf_tag ⇒ String?
Array of OnlyFans Creator User IDs to tag in your message.
67 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 67 optional :rf_tag, String, api_name: :rfTag |
#text ⇒ String?
The welcome message text content. Required unless a media file is present.
73 |
# File 'lib/onlyfans/models/settings/welcome_message_update_params.rb', line 73 optional :text, String |