Class: Onlyfans::Models::SharedTrackingLinkListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/shared_tracking_link_list_params.rb,
sig/onlyfans/models/shared_tracking_link_list_params.rbs

Overview

See Also:

  • Onlyfans::Resources::SharedTrackingLinks#list

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, limit: nil, offset: nil, synchronous: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::SharedTrackingLinkListParams for more details.

background. *

Parameters:

  • account (String)
  • limit (Integer) (defaults to: nil) —

    The number of shared tracking links to return. Default 10

  • offset (Integer) (defaults to: nil) —

    The offset used for pagination. Default 0

  • synchronous (Boolean, nil) (defaults to: nil) —

    Wait for the database sync to finish, instead of running it in the

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 34

Instance Attribute Details

#account ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 13

required :account, String

#limit ⇒ Integer?

The number of shared tracking links to return. Default 10

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


19
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 19

optional :limit, Integer

#offset ⇒ Integer?

The offset used for pagination. Default 0

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


25
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 25

optional :offset, Integer

#synchronous ⇒ Boolean?

Wait for the database sync to finish, instead of running it in the background. Will result in longer response times, use with caution. Default false

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


32
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 32

optional :synchronous, Onlyfans::Internal::Type::Boolean, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/onlyfans/models/shared_tracking_link_list_params.rbs', line 31

def to_hash: -> {