Class: Onlyfans::Models::SmartLinkCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/smart_link_create_params.rb

Overview

Defined Under Namespace

Modules: LinkType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, link_type:, name:, free_trial_days: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::SmartLinkCreateParams for more details.

Parameters:

  • account_id (String)

    The prefixed ID of the account to create the Smart Link for

  • link_type (Symbol, Onlyfans::Models::SmartLinkCreateParams::LinkType)

    The type of Smart Link to create

  • name (String)

    The name of the Smart Link

  • free_trial_days (Integer) (defaults to: nil)

    The number of free trial days (required if ‘link_type` is `free_trial`). Must be

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/smart_link_create_params.rb', line 35

Instance Attribute Details

#account_idString

The prefixed ID of the account to create the Smart Link for

Returns:

  • (String)


14
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 14

required :account_id, String

#free_trial_daysInteger?

The number of free trial days (required if ‘link_type` is `free_trial`). Must be between 1 and 360.

Returns:

  • (Integer, nil)


33
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 33

optional :free_trial_days, Integer

The type of Smart Link to create



20
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 20

required :link_type, enum: -> { Onlyfans::SmartLinkCreateParams::LinkType }

#nameString

The name of the Smart Link

Returns:

  • (String)


26
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 26

required :name, String