Class: Onlyfans::Models::StatisticGetSubscriberMetricsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/statistic_get_subscriber_metrics_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, end_date:, start_date:, detailed: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::StatisticGetSubscriberMetricsParams for more details.

Parameters:

  • account (String)
  • end_date (String)

    The end date for the metrics.

  • start_date (String)

    The start date for the metrics.

  • detailed (Boolean, nil) (defaults to: nil)

    Include paid and free fan metrics. Will slow down the response time, and might t

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/statistic_get_subscriber_metrics_params.rb', line 34

Instance Attribute Details

#accountString

Returns:

  • (String)


13
# File 'lib/onlyfans/models/statistic_get_subscriber_metrics_params.rb', line 13

required :account, String

#detailedBoolean?

Include paid and free fan metrics. Will slow down the response time, and might time out if timeframe is too large. Default = ‘false`

Returns:

  • (Boolean, nil)


32
# File 'lib/onlyfans/models/statistic_get_subscriber_metrics_params.rb', line 32

optional :detailed, Onlyfans::Internal::Type::Boolean, nil?: true

#end_dateString

The end date for the metrics.

Returns:

  • (String)


19
# File 'lib/onlyfans/models/statistic_get_subscriber_metrics_params.rb', line 19

required :end_date, String

#start_dateString

The start date for the metrics.

Returns:

  • (String)


25
# File 'lib/onlyfans/models/statistic_get_subscriber_metrics_params.rb', line 25

required :start_date, String