Class: Onlyfans::Models::Stories::HighlightAddStoryParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/stories/highlight_add_story_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, highlight_id:, path_story_id:, body_story_id:, request_options: {}) ⇒ Object

Parameters:

  • account (String)
  • highlight_id (Integer)
  • path_story_id (String)
  • body_story_id (Integer)

    The ID of the story to add to the highlight

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 32

Instance Attribute Details

#accountString

Returns:

  • (String)


14
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 14

required :account, String

#body_story_idInteger

The ID of the story to add to the highlight

Returns:

  • (Integer)


30
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 30

required :body_story_id, Integer, api_name: :story_id

#highlight_idInteger

Returns:

  • (Integer)


19
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 19

required :highlight_id, Integer

#path_story_idString

Returns:

  • (String)


24
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 24

required :path_story_id, String