Class: Onlyfans::Models::Stories::HighlightCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/stories/highlight_create_params.rb,
sig/onlyfans/models/stories/highlight_create_params.rbs

Overview

See Also:

  • Onlyfans::Resources::Stories::Highlights#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, cover_story_id:, story_ids:, title:, request_options: {}) ⇒ Object

Parameters:

  • account (String)
  • cover_story_id (Integer) —

    The ID of the story to use as the cover for the highlight

  • story_ids (Array<String>) —

    An array of story IDs to include in the highlight

  • title (String) —

    The title of the story highlight

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 34

Instance Attribute Details

#account ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 14

required :account, String

#cover_story_id ⇒ Integer

The ID of the story to use as the cover for the highlight

Parameters:

  • value (Integer)

Returns:

  • (Integer)


20
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 20

required :cover_story_id, Integer, api_name: :coverStoryId

#story_ids ⇒ Array<String>

An array of story IDs to include in the highlight

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


26
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 26

required :story_ids, Onlyfans::Internal::Type::ArrayOf[String], api_name: :storyIds

#title ⇒ String

The title of the story highlight

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 32

required :title, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


33
# File 'sig/onlyfans/models/stories/highlight_create_params.rbs', line 33

def to_hash: -> {