Class: Onlyfans::Models::TrialLinkListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/trial_link_list_params.rb,
sig/onlyfans/models/trial_link_list_params.rbs

Overview

See Also:

  • Onlyfans::Resources::TrialLinks#list

Defined Under Namespace

Modules: Field, Sort

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, limit:, offset:, field: nil, sort: nil, synchronous: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::TrialLinkListParams for more details.

Parameters:

  • account (String)
  • limit (Integer) —

    The number of trial links to return. Default 10

  • offset (Integer) —

    The offset used for pagination. Default 0

  • field (Symbol, Onlyfans::Models::TrialLinkListParams::Field, nil) (defaults to: nil) —

    Sort the results by a field. Default create_date

  • sort (Symbol, Onlyfans::Models::TrialLinkListParams::Sort, nil) (defaults to: nil) —

    Sort the results. Default desc

  • synchronous (Boolean, nil) (defaults to: nil) —

    Wait for the revenue data to finish processing, instead of processing in the bac

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/trial_link_list_params.rb', line 47

Instance Attribute Details

#account ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 13

required :account, String

#field ⇒ Symbol, ...

Sort the results by a field. Default create_date

Parameters:

  • value (Onlyfans::Models::TrialLinkListParams::field, nil)

Returns:



31
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 31

optional :field, enum: -> { Onlyfans::TrialLinkListParams::Field }, nil?: true

#limit ⇒ Integer

The number of trial links to return. Default 10

Parameters:

  • value (Integer)

Returns:

  • (Integer)


19
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 19

required :limit, Integer

#offset ⇒ Integer

The offset used for pagination. Default 0

Parameters:

  • value (Integer)

Returns:

  • (Integer)


25
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 25

required :offset, Integer

#sort ⇒ Symbol, ...

Sort the results. Default desc

Parameters:

  • value (Onlyfans::Models::TrialLinkListParams::sort, nil)

Returns:



37
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 37

optional :sort, enum: -> { Onlyfans::TrialLinkListParams::Sort }, nil?: true

#synchronous ⇒ Boolean?

Wait for the revenue data to finish processing, instead of processing in the background. Will result in longer response times, use with caution. Default false

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


45
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 45

optional :synchronous, Onlyfans::Internal::Type::Boolean, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/onlyfans/models/trial_link_list_params.rb', line 75

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


40
# File 'sig/onlyfans/models/trial_link_list_params.rbs', line 40

def to_hash: -> {