Class: Onlyfans::Models::WebhookCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::WebhookCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/webhook_create_params.rb
Overview
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>?
An array of account IDs to apply the scope to.
-
#account_scope ⇒ String
The account scope for the webhook.
-
#endpoint_url ⇒ String
The URL of your webhook endpoint.
-
#events ⇒ Array<String>
An array of webhook events to subscribe to.
-
#signing_secret ⇒ String?
Optionally, add a signing secret to protect your webhook.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_scope:, endpoint_url:, events:, account_ids: nil, signing_secret: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebhookCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_scope:, endpoint_url:, events:, account_ids: nil, signing_secret: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::WebhookCreateParams for more details.
**List
|
|
# File 'lib/onlyfans/models/webhook_create_params.rb', line 43
|
Instance Attribute Details
#account_ids ⇒ Array<String>?
An array of account IDs to apply the scope to. Required unless account_scope is “global”.
35 |
# File 'lib/onlyfans/models/webhook_create_params.rb', line 35 optional :account_ids, Onlyfans::Internal::Type::ArrayOf[String] |
#account_scope ⇒ String
The account scope for the webhook. Use “global” for all accounts, “inclusive” for only selected accounts, or “exclusive” for all except selected accounts.
15 |
# File 'lib/onlyfans/models/webhook_create_params.rb', line 15 required :account_scope, String |
#endpoint_url ⇒ String
The URL of your webhook endpoint.
21 |
# File 'lib/onlyfans/models/webhook_create_params.rb', line 21 required :endpoint_url, String |
#events ⇒ Array<String>
An array of webhook events to subscribe to. For all options, refer to our **List Available Events** endpoint.
28 |
# File 'lib/onlyfans/models/webhook_create_params.rb', line 28 required :events, Onlyfans::Internal::Type::ArrayOf[String] |
#signing_secret ⇒ String?
Optionally, add a signing secret to protect your webhook.
41 |
# File 'lib/onlyfans/models/webhook_create_params.rb', line 41 optional :signing_secret, String, nil?: true |