Class: Onlyfans::Models::WebhookUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/webhook_update_params.rb,
sig/onlyfans/models/webhook_update_params.rbs

Overview

See Also:

  • Onlyfans::Resources::Webhooks#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(webhook_id:, account_scope:, endpoint_url:, events:, account_ids: nil, enabled: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::WebhookUpdateParams for more details.

**List

Parameters:

  • webhook_id (String)
  • account_scope (String) —

    The account scope for the webhook. Use "global" for all accounts, "inclusive" fo

  • endpoint_url (String) —

    The URL of your webhook endpoint.

  • events (Array<String>) —

    An array of webhook events to subscribe to. For all options, refer to our

  • account_ids (Array<String>) (defaults to: nil) —

    An array of account IDs to apply the scope to. Required unless account_scope is

  • enabled (Boolean, nil) (defaults to: nil) —

    Optionally, enabled/disable the webhook. This will stop/resume the sending of ev

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/webhook_update_params.rb', line 49

Instance Attribute Details

#account_ids ⇒ Array<String>?

An array of account IDs to apply the scope to. Required unless account_scope is "global".

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


40
# File 'lib/onlyfans/models/webhook_update_params.rb', line 40

optional :account_ids, Onlyfans::Internal::Type::ArrayOf[String]

#account_scope ⇒ String

The account scope for the webhook. Use "global" for all accounts, "inclusive" for only selected accounts, or "exclusive" for all except selected accounts.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/onlyfans/models/webhook_update_params.rb', line 20

required :account_scope, String

#enabled ⇒ Boolean?

Optionally, enabled/disable the webhook. This will stop/resume the sending of events, without having to delete the webhook.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


47
# File 'lib/onlyfans/models/webhook_update_params.rb', line 47

optional :enabled, Onlyfans::Internal::Type::Boolean, nil?: true

#endpoint_url ⇒ String

The URL of your webhook endpoint.

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/onlyfans/models/webhook_update_params.rb', line 26

required :endpoint_url, String

#events ⇒ Array<String>

An array of webhook events to subscribe to. For all options, refer to our List Available Events endpoint.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


33
# File 'lib/onlyfans/models/webhook_update_params.rb', line 33

required :events, Onlyfans::Internal::Type::ArrayOf[String]

#webhook_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/onlyfans/models/webhook_update_params.rb', line 13

required :webhook_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


42
# File 'sig/onlyfans/models/webhook_update_params.rbs', line 42

def to_hash: -> {