Class: Onlyfans::Resources::LinkTags

Inherits:
Object
  • Object
show all
Defined in:
lib/onlyfans/resources/link_tags.rb

Overview

APIs for managing tags on free trial links and tracking links

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ LinkTags

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of LinkTags.

Parameters:



34
35
36
# File 'lib/onlyfans/resources/link_tags.rb', line 34

def initialize(client:)
  @client = client
end

Instance Method Details

#list(type: nil, request_options: {}) ⇒ Onlyfans::Models::LinkTagListResponse

Get all existing tags that have been used on free trial links and/or tracking links for this account. This is a free endpoint.

Parameters:

Returns:

See Also:



19
20
21
22
23
24
25
26
27
28
29
# File 'lib/onlyfans/resources/link_tags.rb', line 19

def list(params = {})
  parsed, options = Onlyfans::LinkTagListParams.dump_request(params)
  query = Onlyfans::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "api/link-tags",
    query: query,
    model: Onlyfans::Models::LinkTagListResponse,
    options: options
  )
end