Class: Onlyfans::Resources::Stored

Inherits:
Object
  • Object
show all
Defined in:
lib/onlyfans/resources/stored.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Stored

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Stored.

Parameters:



141
142
143
# File 'lib/onlyfans/resources/stored.rb', line 141

def initialize(client:)
  @client = client
end

Instance Method Details

Some parameter documentations has been truncated, see Models::StoredListSharedTrackingLinksParams for more details.

List all shared Tracking Links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.

Parameters:

Returns:

See Also:



27
28
29
30
31
32
33
34
35
36
37
# File 'lib/onlyfans/resources/stored.rb', line 27

def list_shared_tracking_links(, params = {})
  parsed, options = Onlyfans::StoredListSharedTrackingLinksParams.dump_request(params)
  query = Onlyfans::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["api/%1$s/stored/shared-tracking-links", ],
    query: query,
    model: Onlyfans::Models::StoredListSharedTrackingLinksResponse,
    options: options
  )
end

Some parameter documentations has been truncated, see Models::StoredListSharedTrialLinksParams for more details.

List all shared Free Trial Links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.

Parameters:

Returns:

See Also:



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/onlyfans/resources/stored.rb', line 60

def list_shared_trial_links(, params = {})
  parsed, options = Onlyfans::StoredListSharedTrialLinksParams.dump_request(params)
  query = Onlyfans::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["api/%1$s/stored/shared-trial-links", ],
    query: query,
    model: Onlyfans::Models::StoredListSharedTrialLinksResponse,
    options: options
  )
end

Some parameter documentations has been truncated, see Models::StoredListTrackingLinksParams for more details.

List all stored tracking links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.

Parameters:

Returns:

See Also:



93
94
95
96
97
98
99
100
101
102
103
# File 'lib/onlyfans/resources/stored.rb', line 93

def list_tracking_links(, params = {})
  parsed, options = Onlyfans::StoredListTrackingLinksParams.dump_request(params)
  query = Onlyfans::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["api/%1$s/stored/tracking-links", ],
    query: query,
    model: Onlyfans::Models::StoredListTrackingLinksResponse,
    options: options
  )
end

Some parameter documentations has been truncated, see Models::StoredListTrialLinksParams for more details.

List all stored free trial links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.

Parameters:

Returns:

See Also:



126
127
128
129
130
131
132
133
134
135
136
# File 'lib/onlyfans/resources/stored.rb', line 126

def list_trial_links(, params = {})
  parsed, options = Onlyfans::StoredListTrialLinksParams.dump_request(params)
  query = Onlyfans::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["api/%1$s/stored/trial-links", ],
    query: query,
    model: Onlyfans::Models::StoredListTrialLinksResponse,
    options: options
  )
end