Class: Onlyfans::Models::AuthenticateStartParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/authenticate_start_params.rb

Overview

Defined Under Namespace

Modules: AuthType, ProxyCountry Classes: CustomProxy

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(host: nil, password: nil, port: nil, username: nil) ⇒ Object

Custom proxy configuration. Cannot be used together with proxyCountry.

Parameters:

  • host (String) (defaults to: nil)

    The hostname or IP address of your custom proxy server

  • password (String) (defaults to: nil)

    The password for proxy authentication (optional)

  • port (Integer) (defaults to: nil)

    The port number of your custom proxy server (1-65535)

  • username (String) (defaults to: nil)

    The username for proxy authentication (optional)



# File 'lib/onlyfans/models/authenticate_start_params.rb', line 86

Instance Attribute Details

#auth_idString?

The auth_id from OnlyFans session cookies. Required when auth_type is ‘raw_data`.

Returns:

  • (String, nil)


15
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 15

optional :auth_id, String

#auth_typeSymbol, ...

The authentication method to use. Defaults to ‘email_password` if omitted. Use `mobile_app` to authenticate via the FansAPI Auth+ mobile app (no credential fields required).



23
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 23

optional :auth_type, enum: -> { Onlyfans::AuthenticateStartParams::AuthType }

#cookiesString?

The full cookie string (semicolon-separated). Required when auth_type is ‘raw_data`.

Returns:

  • (String, nil)


30
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 30

optional :cookies, String

#custom_proxyOnlyfans::Models::AuthenticateStartParams::CustomProxy?

Custom proxy configuration. Cannot be used together with proxyCountry.



36
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 36

optional :custom_proxy, -> { Onlyfans::AuthenticateStartParams::CustomProxy }, api_name: :customProxy

#emailString?

The email address of the OnlyFans account. Required when auth_type is ‘email_password`.

Returns:

  • (String, nil)


43
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 43

optional :email, String

#force_connectBoolean?

Set to true to connect the account even if it already exists

Returns:

  • (Boolean, nil)


49
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 49

optional :force_connect, Onlyfans::Internal::Type::Boolean

#nameString?

A display name for the account. If omitted, defaults to the email address or auth_id.

Returns:

  • (String, nil)


56
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 56

optional :name, String

#passwordString?

The password of the OnlyFans account. Required when auth_type is ‘email_password`.

Returns:

  • (String, nil)


63
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 63

optional :password, String

#proxy_countrySymbol, ...

The country of the managed proxy server you want to use. Eg. “us” for United States. Cannot be used together with customProxy.



70
71
72
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 70

optional :proxy_country,
enum: -> { Onlyfans::AuthenticateStartParams::ProxyCountry },
api_name: :proxyCountry

#user_agentString?

The browser User-Agent string. Required when auth_type is ‘raw_data`.

Returns:

  • (String, nil)


78
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 78

optional :user_agent, String

#xbcString?

The X-BC token from request headers. Required when auth_type is ‘raw_data`.

Returns:

  • (String, nil)


84
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 84

optional :xbc, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/onlyfans/models/authenticate_start_params.rb', line 124