Class: Onlyfans::Models::AuthenticateStartParams::CustomProxy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::AuthenticateStartParams::CustomProxy
- Defined in:
- lib/onlyfans/models/authenticate_start_params.rb
Instance Attribute Summary collapse
-
#host ⇒ String?
The hostname or IP address of your custom proxy server.
-
#password ⇒ String?
The password for proxy authentication (optional).
-
#port ⇒ Integer?
The port number of your custom proxy server (1-65535).
-
#username ⇒ String?
The username for proxy authentication (optional).
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Onlyfans::Internal::Type::BaseModel
Instance Attribute Details
#host ⇒ String?
The hostname or IP address of your custom proxy server
133 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 133 optional :host, String |
#password ⇒ String?
The password for proxy authentication (optional)
139 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 139 optional :password, String |
#port ⇒ Integer?
The port number of your custom proxy server (1-65535)
145 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 145 optional :port, Integer |
#username ⇒ String?
The username for proxy authentication (optional)
151 |
# File 'lib/onlyfans/models/authenticate_start_params.rb', line 151 optional :username, String |