Class: Onlyfans::Models::Chats::MessageListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::Chats::MessageListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/chats/message_list_params.rb
Overview
Defined Under Namespace
Modules: Filter
Instance Attribute Summary collapse
- #account ⇒ String
- #chat_id ⇒ String
-
#filter ⇒ Symbol, ...
Filter by certain messages.
-
#first_id ⇒ String?
Use for pagination when ‘order=desc` (newest to oldest).
-
#last_id ⇒ String?
Use for pagination when ‘order=asc` (oldest to newest).
-
#limit ⇒ String?
The number of messages to return (default = 10, max = 100).
-
#order ⇒ String?
Sort order for messages (desc or asc).
-
#skip_users ⇒ String?
Whether to skip user details (all or none).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, chat_id:, filter: nil, first_id: nil, last_id: nil, limit: nil, order: nil, skip_users: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, chat_id:, filter: nil, first_id: nil, last_id: nil, limit: nil, order: nil, skip_users: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::Chats::MessageListParams for more details.
|
|
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 62
|
Instance Attribute Details
#account ⇒ String
14 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 14 required :account, String |
#chat_id ⇒ String
19 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 19 required :chat_id, String |
#filter ⇒ Symbol, ...
Filter by certain messages. Currently, only pins are filterable.
25 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 25 optional :filter, enum: -> { Onlyfans::Chats::MessageListParams::Filter } |
#first_id ⇒ String?
Use for pagination when ‘order=desc` (newest to oldest). Include this message ID as the first message in the results. Used to retrieve messages from e.g. the Search Chat Messages endpoint IDs.
33 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 33 optional :first_id, String, nil?: true |
#last_id ⇒ String?
Use for pagination when ‘order=asc` (oldest to newest). Include this message ID as the first message in the results. WARNING! The response list of messages will also be inverted (oldest messages will be first, opposite to default where `order=desc`).
42 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 42 optional :last_id, String, nil?: true |
#limit ⇒ String?
The number of messages to return (default = 10, max = 100)
48 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 48 optional :limit, String |
#order ⇒ String?
Sort order for messages (desc or asc)
54 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 54 optional :order, String |
#skip_users ⇒ String?
Whether to skip user details (all or none)
60 |
# File 'lib/onlyfans/models/chats/message_list_params.rb', line 60 optional :skip_users, String |