Class: Onlyfans::Models::DataExportCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::DataExportCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/data_export_create_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>?
Array of account prefixed IDs to export data from.
-
#auto_start ⇒ Boolean?
When true, automatically starts the export after creation.
-
#end_date ⇒ String
The end date for the export (ISO 8601 format).
-
#export_columns ⇒ Array<String>?
Array of column names to include in the export (optional, defaults to all columns for the export type).
-
#file_type ⇒ Symbol, Onlyfans::Models::DataExportCreateParams::FileType
The output file format.
-
#options ⇒ Hash{Symbol=>Object}?
Type-specific export options.
-
#start_date ⇒ String
The start date for the export (ISO 8601 format).
-
#type ⇒ Symbol, Onlyfans::Models::DataExportCreateParams::Type
The type of data to export.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(end_date:, file_type:, start_date:, type:, account_ids: nil, auto_start: nil, export_columns: nil, options: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DataExportCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_date:, file_type:, start_date:, type:, account_ids: nil, auto_start: nil, export_columns: nil, options: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::DataExportCreateParams for more details.
|
|
# File 'lib/onlyfans/models/data_export_create_params.rb', line 78
|
Instance Attribute Details
#account_ids ⇒ Array<String>?
Array of account prefixed IDs to export data from. Not required for ‘public_profiles` type.
41 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 41 optional :account_ids, Onlyfans::Internal::Type::ArrayOf[String] |
#auto_start ⇒ Boolean?
When true, automatically starts the export after creation.
47 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 47 optional :auto_start, Onlyfans::Internal::Type::Boolean |
#end_date ⇒ String
The end date for the export (ISO 8601 format).
14 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 14 required :end_date, String |
#export_columns ⇒ Array<String>?
Array of column names to include in the export (optional, defaults to all columns for the export type)
54 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 54 optional :export_columns, Onlyfans::Internal::Type::ArrayOf[String] |
#file_type ⇒ Symbol, Onlyfans::Models::DataExportCreateParams::FileType
The output file format. Supported formats vary by export type: ‘csv` or `xlsx` for transactions, chat_messages, trial_links, tracking_links, smart_links, payouts, chargebacks, public_profiles, fans, followings; `zip` for media_vault.
22 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 22 required :file_type, enum: -> { Onlyfans::DataExportCreateParams::FileType } |
#options ⇒ Hash{Symbol=>Object}?
Type-specific export options. For ‘chat_messages`: `maxMessages` (required per account, max 10,000,000), `maxChats` (optional per-account chat scrape limit), `skipMassMessages` (optional, bool), `chatIds` (optional array of numeric fan/chat IDs; filters output and can drastically reduce totals). For `media_vault`: `mediaType` (required, one of: `all`, `photo`, `gif`, `video`, `audio`). For `fans`: `type` (required, one of: `all`, `active`, `expired`, `latest`). For `followings`: `type` (required, one of: `all`, `active`, `expired`). For `public_profiles`: `query` (optional, full-text search), `gender` (optional, filter: male, female, trans, couple), `minSubscribePrice` (optional, USD), `maxSubscribePrice` (optional, USD), `location` (optional), `minPostsCount` (optional, minimum posts), `minPhotosCount` (optional, minimum photos), `minVideosCount` (optional, minimum videos), `minSubscribersCount` (optional, minimum subscribers), `minJoinDate` (optional, ISO 8601 date), `minLastSeenAt` (optional, ISO 8601 date), `createdAtFrom` (optional, ISO 8601 date, profile added to DB after), `createdAtTo` (optional, ISO 8601 date, profile added to DB before), `instagram` (optional), `twitter` (optional), `tiktok` (optional), `maxResults` (optional, limit results).
76 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 76 optional :options, Onlyfans::Internal::Type::HashOf[Onlyfans::Internal::Type::Unknown] |
#start_date ⇒ String
The start date for the export (ISO 8601 format).
28 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 28 required :start_date, String |
#type ⇒ Symbol, Onlyfans::Models::DataExportCreateParams::Type
The type of data to export
34 |
# File 'lib/onlyfans/models/data_export_create_params.rb', line 34 required :type, enum: -> { Onlyfans::DataExportCreateParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/onlyfans/models/data_export_create_params.rb', line 110
|