Class: Onlyfans::Models::MassMessagingSendParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::MassMessagingSendParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/mass_messaging_send_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
-
#excluded_lists ⇒ Array<String>?
Array of user list IDs that the mass message will NOT be sent to.
-
#giphy_id ⇒ String?
The ID of the Giphy GIF to attach to the message.
-
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden.
-
#media_files ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, or OF vault IDs.
-
#previews ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, OF vault IDs, or integer indices referencing uploaded files in `mediaFiles`.
-
#price ⇒ Integer?
Price for paid content (0 or between 3-200).
-
#rf_guest ⇒ String?
Array of OnlyFans Release Form Guest IDs to tag in your mass message.
-
#rf_partner ⇒ String?
Array of OnlyFans Release Form Partners IDs to tag in your mass message.
-
#rf_tag ⇒ String?
Array of OnlyFans Creator User IDs to tag in your mass message.
-
#save_for_later ⇒ Boolean?
Add your message to the “Saved for later” queue.
-
#scheduled_date ⇒ String?
Schedule the chat message in the future (UTC timezone).
-
#text ⇒ String
The message text content.
-
#user_ids ⇒ Array<String>?
Array of user IDs that the mass message will be sent to.
-
#user_lists ⇒ Array<String>?
Array of user list IDs that the mass message will be sent to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, text:, excluded_lists: nil, giphy_id: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, rf_guest: nil, rf_partner: nil, rf_tag: nil, save_for_later: nil, scheduled_date: nil, user_ids: nil, user_lists: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MassMessagingSendParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, text:, excluded_lists: nil, giphy_id: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, rf_guest: nil, rf_partner: nil, rf_tag: nil, save_for_later: nil, scheduled_date: nil, user_ids: nil, user_lists: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::MassMessagingSendParams for more details.
**mediaFi
|
|
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 106
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 13 required :account, String |
#excluded_lists ⇒ Array<String>?
Array of user list IDs that the mass message will NOT be sent to.
25 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 25 optional :excluded_lists, Onlyfans::Internal::Type::ArrayOf[String], api_name: :excludedLists |
#giphy_id ⇒ String?
The ID of the Giphy GIF to attach to the message. Get IDs from the Giphy listing endpoints (‘/giphy/trending`, `/giphy/search`).
32 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 32 optional :giphy_id, String, api_name: :giphyId |
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden
38 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 38 optional :locked_text, Onlyfans::Internal::Type::Boolean, api_name: :lockedText |
#media_files ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, or OF vault IDs. Will be hidden if `price` is provided.
45 46 47 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 45 optional :media_files, Onlyfans::Internal::Type::ArrayOf[Onlyfans::Internal::Type::Unknown], api_name: :mediaFiles |
#previews ⇒ Array<Object>?
Direct file uploads, OFAPI ‘ofapi_media_` IDs, OF vault IDs, or integer indices referencing uploaded files in `mediaFiles`. Will be shown if `price` is provided.
55 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 55 optional :previews, Onlyfans::Internal::Type::ArrayOf[Onlyfans::Internal::Type::Unknown] |
#price ⇒ Integer?
Price for paid content (0 or between 3-200). In case this is not zero, mediaFiles is required
62 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 62 optional :price, Integer |
#rf_guest ⇒ String?
Array of OnlyFans Release Form Guest IDs to tag in your mass message
68 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 68 optional :rf_guest, String, api_name: :rfGuest |
#rf_partner ⇒ String?
Array of OnlyFans Release Form Partners IDs to tag in your mass message
74 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 74 optional :rf_partner, String, api_name: :rfPartner |
#rf_tag ⇒ String?
Array of OnlyFans Creator User IDs to tag in your mass message
80 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 80 optional :rf_tag, String, api_name: :rfTag |
#save_for_later ⇒ Boolean?
Add your message to the “Saved for later” queue.
86 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 86 optional :save_for_later, Onlyfans::Internal::Type::Boolean, api_name: :saveForLater |
#scheduled_date ⇒ String?
Schedule the chat message in the future (UTC timezone).
92 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 92 optional :scheduled_date, String, api_name: :scheduledDate |
#text ⇒ String
The message text content
19 |
# File 'lib/onlyfans/models/mass_messaging_send_params.rb', line 19 required :text, String |