Class: Onlyfans::Models::MassMessagingUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::MassMessagingUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/mass_messaging_update_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
-
#giphy_id ⇒ String?
The ID of the Giphy GIF to attach to the message.
- #id ⇒ String
-
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden.
-
#media_files ⇒ Array<String>?
Array of media file upload prefixed_ids, or OF media IDs (required if price is not 0).
-
#previews ⇒ Array<String>?
Array of media file upload prefixed_ids, or OF media IDs (required if price is not 0).
-
#price ⇒ Integer?
Price for paid content (0 or between 3-200).
-
#scheduled_date ⇒ String?
Schedule the chat message in the future (UTC timezone).
-
#text ⇒ String
The message text content.
-
#user_ids ⇒ Array<String>?
Array of user IDs that the mass message will be sent to.
-
#user_lists ⇒ Array<String>?
Array of user list IDs that the mass message will be sent to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, id:, text:, giphy_id: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, scheduled_date: nil, user_ids: nil, user_lists: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MassMessagingUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, id:, text:, giphy_id: nil, locked_text: nil, media_files: nil, previews: nil, price: nil, scheduled_date: nil, user_ids: nil, user_lists: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::MassMessagingUpdateParams for more details.
**mediaFi
|
|
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 79
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 13 required :account, String |
#giphy_id ⇒ String?
The ID of the Giphy GIF to attach to the message. Get IDs from the Giphy listing endpoints (‘/giphy/trending`, `/giphy/search`).
31 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 31 optional :giphy_id, String, api_name: :giphyId |
#id ⇒ String
18 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 18 required :id, String |
#locked_text ⇒ Boolean?
Whether the text should be shown or hidden
37 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 37 optional :locked_text, Onlyfans::Internal::Type::Boolean, api_name: :lockedText |
#media_files ⇒ Array<String>?
Array of media file upload prefixed_ids, or OF media IDs (required if price is not 0). Will be hidden if ‘price` is provided.
44 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 44 optional :media_files, Onlyfans::Internal::Type::ArrayOf[String], api_name: :mediaFiles |
#previews ⇒ Array<String>?
Array of media file upload prefixed_ids, or OF media IDs (required if price is not 0). Will be shown if ‘price` is provided. All `previews` values must also exist in the `mediaFiles` array.
52 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 52 optional :previews, Onlyfans::Internal::Type::ArrayOf[String] |
#price ⇒ Integer?
Price for paid content (0 or between 3-200). In case this is not zero, mediaFiles is required
59 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 59 optional :price, Integer |
#scheduled_date ⇒ String?
Schedule the chat message in the future (UTC timezone).
65 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 65 optional :scheduled_date, String, api_name: :scheduledDate |
#text ⇒ String
The message text content
24 |
# File 'lib/onlyfans/models/mass_messaging_update_params.rb', line 24 required :text, String |