Class: Onlyfans::Models::Media::VaultListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::Media::VaultListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/media/vault_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #account ⇒ String
-
#field ⇒ Symbol, ...
Sort the results by a field.
-
#limit ⇒ Integer?
Number of media to return per page (10 - 100).
-
#list ⇒ Integer?
Only show media items from a specific list (category).
-
#offset ⇒ Integer?
The offset used for pagination.
-
#query ⇒ String?
Optionally, search for a text query.
-
#sort ⇒ Symbol, ...
Sort the results.
-
#type ⇒ Symbol, ...
Filter the results by a media type.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account:, field: nil, limit: nil, list: nil, offset: nil, query: nil, sort: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see VaultListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, field: nil, limit: nil, list: nil, offset: nil, query: nil, sort: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::Media::VaultListParams for more details.
Vaul
|
|
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 59
|
Instance Attribute Details
#account ⇒ String
14 |
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 14 required :account, String |
#field ⇒ Symbol, ...
Sort the results by a field. Default ‘recent`
20 |
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 20 optional :field, enum: -> { Onlyfans::Media::VaultListParams::Field } |
#limit ⇒ Integer?
Number of media to return per page (10 - 100). Default: ‘24`
26 |
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 26 optional :limit, Integer |
#list ⇒ Integer?
Only show media items from a specific list (category). **Refer to our Media Vault Lists endpoints.**
33 |
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 33 optional :list, Integer |
#offset ⇒ Integer?
The offset used for pagination. Default ‘0`
39 |
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 39 optional :offset, Integer |
#query ⇒ String?
Optionally, search for a text query.
45 |
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 45 optional :query, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/onlyfans/models/media/vault_list_params.rb', line 90
|