Module: Onlyfans::Models::MediaUploadParams::Type
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/onlyfans/models/media_upload_params.rb
Overview
Set to ‘avatar` if this file will be used as a profile picture, `header` for a profile banner, or keep empty if this file will be for anything else.
Constant Summary collapse
- DEFAULT =
:default- AVATAR =
:avatar- HEADER =
:header
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/onlyfans/models/media_upload_params.rb', line 68
|