Class: Onlyfans::Models::PostListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::PostListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/post_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #account ⇒ String
-
#counters ⇒ Boolean?
Set to true to include an array of counters (see example responses).
-
#limit ⇒ Integer?
Number of posts to return (default = 10).
-
#minimum_publish_date ⇒ String?
Filter posts by minimum publish date.
-
#offset ⇒ Integer?
Number of posts to skip for pagination.
-
#order ⇒ Symbol, ...
Order the returned posts (default = publish_date).
-
#pinned ⇒ Boolean?
Set to true to only show pinned posts.
-
#query ⇒ String?
Search query to filter posts.
-
#sort ⇒ Symbol, ...
Sort the returned posts (default = desc).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, counters: nil, limit: nil, minimum_publish_date: nil, offset: nil, order: nil, pinned: nil, query: nil, sort: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/onlyfans/models/post_list_params.rb', line 63
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/post_list_params.rb', line 13 required :account, String |
#counters ⇒ Boolean?
Set to true to include an array of counters (see example responses)
19 |
# File 'lib/onlyfans/models/post_list_params.rb', line 19 optional :counters, Onlyfans::Internal::Type::Boolean |
#limit ⇒ Integer?
Number of posts to return (default = 10)
25 |
# File 'lib/onlyfans/models/post_list_params.rb', line 25 optional :limit, Integer |
#minimum_publish_date ⇒ String?
Filter posts by minimum publish date
31 |
# File 'lib/onlyfans/models/post_list_params.rb', line 31 optional :minimum_publish_date, String |
#offset ⇒ Integer?
Number of posts to skip for pagination
37 |
# File 'lib/onlyfans/models/post_list_params.rb', line 37 optional :offset, Integer |
#order ⇒ Symbol, ...
Order the returned posts (default = publish_date)
43 |
# File 'lib/onlyfans/models/post_list_params.rb', line 43 optional :order, enum: -> { Onlyfans::PostListParams::Order } |
#pinned ⇒ Boolean?
Set to true to only show pinned posts
49 |
# File 'lib/onlyfans/models/post_list_params.rb', line 49 optional :pinned, Onlyfans::Internal::Type::Boolean |
#query ⇒ String?
Search query to filter posts
55 |
# File 'lib/onlyfans/models/post_list_params.rb', line 55 optional :query, String |
#sort ⇒ Symbol, ...
Sort the returned posts (default = desc)
61 |
# File 'lib/onlyfans/models/post_list_params.rb', line 61 optional :sort, enum: -> { Onlyfans::PostListParams::Sort } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/onlyfans/models/post_list_params.rb', line 92
|