Class: Onlyfans::Models::PostUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::PostUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/post_update_params.rb
Overview
Defined Under Namespace
Modules: VotingType
Instance Attribute Summary collapse
- #account ⇒ String
-
#expire_days ⇒ Integer?
Number of days after which the post will expire.
-
#fund_raising_target_amount ⇒ Integer?
Add a fundraising target to your post.
-
#fund_raising_tips_presets ⇒ Array<String>?
Specify which tip amounts will be listed under the fundraising card.
-
#label_ids ⇒ String?
Array of OF label IDs.
-
#media_files ⇒ String?
Array of OFAPI ‘ofapi_media_` IDs, or OF media IDs.
- #post_id ⇒ Integer
-
#price ⇒ Integer?
Price for paid content (0 or between 3-100).
-
#rf_tag ⇒ String?
Array OnlyFans creator user IDs to tag in your post.
-
#save_for_later ⇒ Boolean?
Add your post to the “Saved for later” queue.
-
#scheduled_date ⇒ String?
Schedule your post in the future (UTC timezone).
-
#text ⇒ String
The post text content.
-
#voting_correct_index ⇒ Integer?
The array key of your quiz’ correct answer.
-
#voting_due ⇒ Integer?
The due date (in days) of your poll/quiz.
-
#voting_options ⇒ Array<String>?
The options of your poll/quiz.
-
#voting_type ⇒ Symbol, ...
Include a poll or quiz within your post.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, post_id:, text:, expire_days: nil, fund_raising_target_amount: nil, fund_raising_tips_presets: nil, label_ids: nil, media_files: nil, price: nil, rf_tag: nil, save_for_later: nil, scheduled_date: nil, voting_correct_index: nil, voting_due: nil, voting_options: nil, voting_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PostUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, post_id:, text:, expire_days: nil, fund_raising_target_amount: nil, fund_raising_tips_presets: nil, label_ids: nil, media_files: nil, price: nil, rf_tag: nil, save_for_later: nil, scheduled_date: nil, voting_correct_index: nil, voting_due: nil, voting_options: nil, voting_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::PostUpdateParams for more details.
**mediaFi
|
|
# File 'lib/onlyfans/models/post_update_params.rb', line 112
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/post_update_params.rb', line 13 required :account, String |
#expire_days ⇒ Integer?
Number of days after which the post will expire. Between 1 and 30 days. Keep empty for no expiration.
31 |
# File 'lib/onlyfans/models/post_update_params.rb', line 31 optional :expire_days, Integer, api_name: :expireDays |
#fund_raising_target_amount ⇒ Integer?
Add a fundraising target to your post. If present, value must be at least 10.
37 |
# File 'lib/onlyfans/models/post_update_params.rb', line 37 optional :fund_raising_target_amount, Integer, api_name: :fundRaisingTargetAmount |
#fund_raising_tips_presets ⇒ Array<String>?
Specify which tip amounts will be listed under the fundraising card. Required with ‘fundRaisingTargetAmount`, and you must provide at least 1 option. Array items cannot be higher than the `fundRaisingTargetAmount`.
45 46 47 |
# File 'lib/onlyfans/models/post_update_params.rb', line 45 optional :fund_raising_tips_presets, Onlyfans::Internal::Type::ArrayOf[String], api_name: :fundRaisingTipsPresets |
#label_ids ⇒ String?
Array of OF label IDs. Refer to our ‘/posts/labels` endpoint.
53 |
# File 'lib/onlyfans/models/post_update_params.rb', line 53 optional :label_ids, String, api_name: :labelIds |
#media_files ⇒ String?
Array of OFAPI ‘ofapi_media_` IDs, or OF media IDs
59 |
# File 'lib/onlyfans/models/post_update_params.rb', line 59 optional :media_files, String, api_name: :mediaFiles |
#post_id ⇒ Integer
18 |
# File 'lib/onlyfans/models/post_update_params.rb', line 18 required :post_id, Integer |
#price ⇒ Integer?
Price for paid content (0 or between 3-100). In case this is not zero, mediaFiles is required
66 |
# File 'lib/onlyfans/models/post_update_params.rb', line 66 optional :price, Integer |
#rf_tag ⇒ String?
Array OnlyFans creator user IDs to tag in your post
72 |
# File 'lib/onlyfans/models/post_update_params.rb', line 72 optional :rf_tag, String, api_name: :rfTag |
#save_for_later ⇒ Boolean?
Add your post to the “Saved for later” queue.
78 |
# File 'lib/onlyfans/models/post_update_params.rb', line 78 optional :save_for_later, Onlyfans::Internal::Type::Boolean, api_name: :saveForLater |
#scheduled_date ⇒ String?
Schedule your post in the future (UTC timezone).
84 |
# File 'lib/onlyfans/models/post_update_params.rb', line 84 optional :scheduled_date, String, api_name: :scheduledDate |
#text ⇒ String
The post text content
24 |
# File 'lib/onlyfans/models/post_update_params.rb', line 24 required :text, String |
#voting_correct_index ⇒ Integer?
The array key of your quiz’ correct answer. Required when ‘votingType` is “quiz”. Keep in mind that arrays start at `0`
91 |
# File 'lib/onlyfans/models/post_update_params.rb', line 91 optional :voting_correct_index, Integer, api_name: :votingCorrectIndex |
#voting_due ⇒ Integer?
The due date (in days) of your poll/quiz. Can be 1, 3, 7 or 30 days. Can only be filled with ‘votingType`.
98 |
# File 'lib/onlyfans/models/post_update_params.rb', line 98 optional :voting_due, Integer, api_name: :votingDue |
#voting_options ⇒ Array<String>?
The options of your poll/quiz. Required with ‘votingType`.
104 |
# File 'lib/onlyfans/models/post_update_params.rb', line 104 optional :voting_options, Onlyfans::Internal::Type::ArrayOf[String], api_name: :votingOptions |
#voting_type ⇒ Symbol, ...
Include a poll or quiz within your post.
110 |
# File 'lib/onlyfans/models/post_update_params.rb', line 110 optional :voting_type, enum: -> { Onlyfans::PostUpdateParams::VotingType }, api_name: :votingType |