Class: Onlyfans::Models::Posts::CommentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::Posts::CommentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/posts/comment_create_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
-
#answer_to ⇒ Integer?
The ID of the comment to which this comment is a reply.
-
#giphy_id ⇒ String?
The ID of the Giphy to include in the comment.
- #post_id ⇒ String
-
#text ⇒ String
The text of the comment.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account:, post_id:, text:, answer_to: nil, giphy_id: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, post_id:, text:, answer_to: nil, giphy_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/onlyfans/models/posts/comment_create_params.rb', line 39
|
Instance Attribute Details
#account ⇒ String
14 |
# File 'lib/onlyfans/models/posts/comment_create_params.rb', line 14 required :account, String |
#answer_to ⇒ Integer?
The ID of the comment to which this comment is a reply.
31 |
# File 'lib/onlyfans/models/posts/comment_create_params.rb', line 31 optional :answer_to, Integer |
#giphy_id ⇒ String?
The ID of the Giphy to include in the comment.
37 |
# File 'lib/onlyfans/models/posts/comment_create_params.rb', line 37 optional :giphy_id, String |
#post_id ⇒ String
19 |
# File 'lib/onlyfans/models/posts/comment_create_params.rb', line 19 required :post_id, String |
#text ⇒ String
The text of the comment.
25 |
# File 'lib/onlyfans/models/posts/comment_create_params.rb', line 25 required :text, String |