Class: Onlyfans::Models::SharedTrackingLinkListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::SharedTrackingLinkListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/shared_tracking_link_list_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
-
#limit ⇒ Integer?
The number of shared tracking links to return.
-
#offset ⇒ Integer?
The offset used for pagination.
-
#synchronous ⇒ Boolean?
Wait for the database sync to finish, instead of running it in the background.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account:, limit: nil, offset: nil, synchronous: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SharedTrackingLinkListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, limit: nil, offset: nil, synchronous: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::SharedTrackingLinkListParams for more details.
background. *
|
|
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 34
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 13 required :account, String |
#limit ⇒ Integer?
The number of shared tracking links to return. Default ‘10`
19 |
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 19 optional :limit, Integer |
#offset ⇒ Integer?
The offset used for pagination. Default ‘0`
25 |
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 25 optional :offset, Integer |
#synchronous ⇒ Boolean?
Wait for the database sync to finish, instead of running it in the background. **Will result in longer response times, use with caution**. Default ‘false`
32 |
# File 'lib/onlyfans/models/shared_tracking_link_list_params.rb', line 32 optional :synchronous, Onlyfans::Internal::Type::Boolean, nil?: true |