Class: Onlyfans::Models::SmartLinkCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::SmartLinkCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/smart_link_create_params.rb
Overview
Defined Under Namespace
Modules: LinkType
Instance Attribute Summary collapse
-
#account_id ⇒ String
The prefixed ID of the account to create the Smart Link for.
-
#free_trial_days ⇒ Integer?
The number of free trial days (required if ‘link_type` is `free_trial`).
-
#link_type ⇒ Symbol, Onlyfans::Models::SmartLinkCreateParams::LinkType
The type of Smart Link to create.
-
#name ⇒ String
The name of the Smart Link.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_id:, link_type:, name:, free_trial_days: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SmartLinkCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, link_type:, name:, free_trial_days: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::SmartLinkCreateParams for more details.
|
|
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 35
|
Instance Attribute Details
#account_id ⇒ String
The prefixed ID of the account to create the Smart Link for
14 |
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 14 required :account_id, String |
#free_trial_days ⇒ Integer?
The number of free trial days (required if ‘link_type` is `free_trial`). Must be between 1 and 360.
33 |
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 33 optional :free_trial_days, Integer |
#link_type ⇒ Symbol, Onlyfans::Models::SmartLinkCreateParams::LinkType
The type of Smart Link to create
20 |
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 20 required :link_type, enum: -> { Onlyfans::SmartLinkCreateParams::LinkType } |
#name ⇒ String
The name of the Smart Link
26 |
# File 'lib/onlyfans/models/smart_link_create_params.rb', line 26 required :name, String |