Class: Onlyfans::Models::SmartLinkPostbackCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/smart_link_postback_create_params.rb

Overview

Defined Under Namespace

Modules: SmartLinkScope

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(conversion_types:, smart_link_scope:, url:, smart_link_ids: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::SmartLinkPostbackCreateParams for more details.

Parameters:

  • conversion_types (Array<String>)

    One or more Smart Link conversion types that should trigger this postback.

  • smart_link_scope (Symbol, Onlyfans::Models::SmartLinkPostbackCreateParams::SmartLinkScope)

    ‘global` fires for all Smart Links. `campaign_specific` fires only for selected

  • url (String)

    The destination URL. Variables such as ‘click_id`, `fbclid`, `gclid`, and

  • smart_link_ids (Array<String>) (defaults to: nil)

    Smart Link ULIDs. Required when ‘smart_link_scope` is `campaign_specific`.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/smart_link_postback_create_params.rb', line 36

Instance Attribute Details

#conversion_typesArray<String>

One or more Smart Link conversion types that should trigger this postback.

Returns:

  • (Array<String>)


14
# File 'lib/onlyfans/models/smart_link_postback_create_params.rb', line 14

required :conversion_types, Onlyfans::Internal::Type::ArrayOf[String]

Smart Link ULIDs. Required when ‘smart_link_scope` is `campaign_specific`.

Returns:

  • (Array<String>, nil)


34
# File 'lib/onlyfans/models/smart_link_postback_create_params.rb', line 34

optional :smart_link_ids, Onlyfans::Internal::Type::ArrayOf[String]

‘global` fires for all Smart Links. `campaign_specific` fires only for selected Smart Links.



21
# File 'lib/onlyfans/models/smart_link_postback_create_params.rb', line 21

required :smart_link_scope, enum: -> { Onlyfans::SmartLinkPostbackCreateParams::SmartLinkScope }

#urlString

The destination URL. Variables such as ‘click_id`, `fbclid`, `gclid`, and `ttclid` are replaced when the postback is dispatched.

Returns:

  • (String)


28
# File 'lib/onlyfans/models/smart_link_postback_create_params.rb', line 28

required :url, String