Class: Onlyfans::Models::SmartLinkPostbackUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/smart_link_postback_update_params.rb

Overview

Defined Under Namespace

Modules: SmartLinkScope

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(postback_id:, conversion_types:, smart_link_scope:, url:, smart_link_ids: nil, request_options: {}) ⇒ Object

Parameters:

  • postback_id (Integer)
  • conversion_types (Array<String>)

    One or more Smart Link conversion types that should trigger this postback.

  • smart_link_scope (Symbol, Onlyfans::Models::SmartLinkPostbackUpdateParams::SmartLinkScope)

    ‘global` or `campaign_specific`.

  • url (String)

    The destination URL.

  • smart_link_ids (Array<String>) (defaults to: nil)

    Smart Link ULIDs. Required when ‘smart_link_scope` is `campaign_specific`.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/smart_link_postback_update_params.rb', line 39

Instance Attribute Details

#conversion_typesArray<String>

One or more Smart Link conversion types that should trigger this postback.

Returns:

  • (Array<String>)


19
# File 'lib/onlyfans/models/smart_link_postback_update_params.rb', line 19

required :conversion_types, Onlyfans::Internal::Type::ArrayOf[String]

#postback_idInteger

Returns:

  • (Integer)


13
# File 'lib/onlyfans/models/smart_link_postback_update_params.rb', line 13

required :postback_id, Integer

Smart Link ULIDs. Required when ‘smart_link_scope` is `campaign_specific`.

Returns:

  • (Array<String>, nil)


37
# File 'lib/onlyfans/models/smart_link_postback_update_params.rb', line 37

optional :smart_link_ids, Onlyfans::Internal::Type::ArrayOf[String]

‘global` or `campaign_specific`.



25
# File 'lib/onlyfans/models/smart_link_postback_update_params.rb', line 25

required :smart_link_scope, enum: -> { Onlyfans::SmartLinkPostbackUpdateParams::SmartLinkScope }

#urlString

The destination URL.

Returns:

  • (String)


31
# File 'lib/onlyfans/models/smart_link_postback_update_params.rb', line 31

required :url, String