Class: Onlyfans::Models::Stories::HighlightAddStoryParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::Stories::HighlightAddStoryParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/stories/highlight_add_story_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
-
#body_story_id ⇒ Integer
The ID of the story to add to the highlight.
- #highlight_id ⇒ Integer
- #path_story_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account:, highlight_id:, path_story_id:, body_story_id:, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, highlight_id:, path_story_id:, body_story_id:, request_options: {}) ⇒ Object
|
|
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 32
|
Instance Attribute Details
#account ⇒ String
14 |
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 14 required :account, String |
#body_story_id ⇒ Integer
The ID of the story to add to the highlight
30 |
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 30 required :body_story_id, Integer, api_name: :story_id |
#highlight_id ⇒ Integer
19 |
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 19 required :highlight_id, Integer |
#path_story_id ⇒ String
24 |
# File 'lib/onlyfans/models/stories/highlight_add_story_params.rb', line 24 required :path_story_id, String |