Class: Onlyfans::Models::Stories::HighlightCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::Stories::HighlightCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/stories/highlight_create_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
-
#cover_story_id ⇒ Integer
The ID of the story to use as the cover for the highlight.
-
#story_ids ⇒ Array<String>
An array of story IDs to include in the highlight.
-
#title ⇒ String
The title of the story highlight.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account:, cover_story_id:, story_ids:, title:, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, cover_story_id:, story_ids:, title:, request_options: {}) ⇒ Object
|
|
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 34
|
Instance Attribute Details
#account ⇒ String
14 |
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 14 required :account, String |
#cover_story_id ⇒ Integer
The ID of the story to use as the cover for the highlight
20 |
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 20 required :cover_story_id, Integer, api_name: :coverStoryId |
#story_ids ⇒ Array<String>
An array of story IDs to include in the highlight
26 |
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 26 required :story_ids, Onlyfans::Internal::Type::ArrayOf[String], api_name: :storyIds |
#title ⇒ String
The title of the story highlight
32 |
# File 'lib/onlyfans/models/stories/highlight_create_params.rb', line 32 required :title, String |