Class: Onlyfans::Models::TrackingLinkListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/tracking_link_list_params.rb

Overview

Defined Under Namespace

Modules: Sort, Sortby

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, end_date: nil, limit: nil, offset: nil, sort: nil, sortby: nil, start_date: nil, synchronous: nil, with_deleted: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::TrackingLinkListParams for more details.

Parameters:

  • account (String)
  • end_date (String, nil) (defaults to: nil)

    The end date for Tracking Links. Keep empty to get all.

  • limit (Integer, nil) (defaults to: nil)

    The number of tracking links to return. Default ‘3`

  • offset (Integer, nil) (defaults to: nil)

    The offset used for pagination. Default ‘0`

  • sort (Symbol, Onlyfans::Models::TrackingLinkListParams::Sort, nil) (defaults to: nil)

    Sort the results. Default ‘desc`

  • sortby (Symbol, Onlyfans::Models::TrackingLinkListParams::Sortby, nil) (defaults to: nil)

    Sort by subscriber count (claims), or creation date

  • start_date (String, nil) (defaults to: nil)

    The start date for Tracking Links. Keep empty to get all.

  • synchronous (Boolean, nil) (defaults to: nil)

    Wait for the revenue data to finish processing, instead of processing in the bac

  • with_deleted (Boolean, nil) (defaults to: nil)

    Whether or not to include deleted tracking links in the response. Default ‘false

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 66

Instance Attribute Details

#accountString

Returns:

  • (String)


13
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 13

required :account, String

#end_dateString?

The end date for Tracking Links. Keep empty to get all.

Returns:

  • (String, nil)


19
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 19

optional :end_date, String, nil?: true

#limitInteger?

The number of tracking links to return. Default ‘3`

Returns:

  • (Integer, nil)


25
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 25

optional :limit, Integer, nil?: true

#offsetInteger?

The offset used for pagination. Default ‘0`

Returns:

  • (Integer, nil)


31
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 31

optional :offset, Integer, nil?: true

#sortSymbol, ...

Sort the results. Default ‘desc`



37
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 37

optional :sort, enum: -> { Onlyfans::TrackingLinkListParams::Sort }, nil?: true

#sortbySymbol, ...

Sort by subscriber count (claims), or creation date



43
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 43

optional :sortby, enum: -> { Onlyfans::TrackingLinkListParams::Sortby }, nil?: true

#start_dateString?

The start date for Tracking Links. Keep empty to get all.

Returns:

  • (String, nil)


49
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 49

optional :start_date, String, nil?: true

#synchronousBoolean?

Wait for the revenue data to finish processing, instead of processing in the background. **Will result in longer response times, use with caution**. Default ‘false`

Returns:

  • (Boolean, nil)


57
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 57

optional :synchronous, Onlyfans::Internal::Type::Boolean, nil?: true

#with_deletedBoolean?

Whether or not to include deleted tracking links in the response. Default ‘false`

Returns:

  • (Boolean, nil)


64
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 64

optional :with_deleted, Onlyfans::Internal::Type::Boolean, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 97