Class: Onlyfans::Models::TrackingLinkListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::TrackingLinkListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/tracking_link_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #account ⇒ String
-
#end_date ⇒ String?
The end date for Tracking Links.
-
#limit ⇒ Integer?
The number of tracking links to return.
-
#offset ⇒ Integer?
The offset used for pagination.
-
#sort ⇒ Symbol, ...
Sort the results.
-
#sortby ⇒ Symbol, ...
Sort by subscriber count (claims), or creation date.
-
#start_date ⇒ String?
The start date for Tracking Links.
-
#synchronous ⇒ Boolean?
Wait for the revenue data to finish processing, instead of processing in the background.
-
#with_deleted ⇒ Boolean?
Whether or not to include deleted tracking links in the response.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account:, end_date: nil, limit: nil, offset: nil, sort: nil, sortby: nil, start_date: nil, synchronous: nil, with_deleted: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TrackingLinkListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, end_date: nil, limit: nil, offset: nil, sort: nil, sortby: nil, start_date: nil, synchronous: nil, with_deleted: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::TrackingLinkListParams for more details.
|
|
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 66
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 13 required :account, String |
#end_date ⇒ String?
The end date for Tracking Links. Keep empty to get all.
19 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 19 optional :end_date, String, nil?: true |
#limit ⇒ Integer?
The number of tracking links to return. Default ‘3`
25 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 25 optional :limit, Integer, nil?: true |
#offset ⇒ Integer?
The offset used for pagination. Default ‘0`
31 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 31 optional :offset, Integer, nil?: true |
#sort ⇒ Symbol, ...
Sort the results. Default ‘desc`
37 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 37 optional :sort, enum: -> { Onlyfans::TrackingLinkListParams::Sort }, nil?: true |
#sortby ⇒ Symbol, ...
Sort by subscriber count (claims), or creation date
43 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 43 optional :sortby, enum: -> { Onlyfans::TrackingLinkListParams::Sortby }, nil?: true |
#start_date ⇒ String?
The start date for Tracking Links. Keep empty to get all.
49 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 49 optional :start_date, String, nil?: true |
#synchronous ⇒ Boolean?
Wait for the revenue data to finish processing, instead of processing in the background. **Will result in longer response times, use with caution**. Default ‘false`
57 |
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 57 optional :synchronous, Onlyfans::Internal::Type::Boolean, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/onlyfans/models/tracking_link_list_params.rb', line 97
|