Class: Onlyfans::Models::TrialLinkCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/trial_link_create_params.rb

Overview

Defined Under Namespace

Modules: Duration, OfferLimit

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account:, duration:, offer_expiration:, offer_limit:, name: nil, tags: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::TrialLinkCreateParams for more details.

Parameters:

  • account (String)
  • duration (Integer, Onlyfans::Models::TrialLinkCreateParams::Duration)

    The duration of the free trial **in days**. Must be 1, 3, 7, 14,

  • offer_expiration (Integer)

    The trial link expiration **in days (from now)**. Must either be 0 (to never

  • offer_limit (Integer, Onlyfans::Models::TrialLinkCreateParams::OfferLimit)

    How many people can use this offer. Must either be 0 (for no limit), or a nu

  • name (String, nil) (defaults to: nil)

    The name of the trail link (optional). Cannot be longer than 64 characters.

  • tags (Array<String>) (defaults to: nil)

    Array of tag names to add to the trial link.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/trial_link_create_params.rb', line 48

Instance Attribute Details

#accountString

Returns:

  • (String)


13
# File 'lib/onlyfans/models/trial_link_create_params.rb', line 13

required :account, String

#durationInteger, Onlyfans::Models::TrialLinkCreateParams::Duration

The duration of the free trial **in days**. Must be 1, 3, 7, 14, 30 (1 month), 90 (3 months), 180 (6 months), or 360 (12 months).



20
# File 'lib/onlyfans/models/trial_link_create_params.rb', line 20

required :duration, enum: -> { Onlyfans::TrialLinkCreateParams::Duration }

#nameString?

The name of the trail link (optional). Cannot be longer than 64 characters.

Returns:

  • (String, nil)


40
# File 'lib/onlyfans/models/trial_link_create_params.rb', line 40

optional :name, String, nil?: true

#offer_expirationInteger

The trial link expiration **in days (from now)**. Must either be 0 (to never expire), or a number between 1 and 30.

Returns:

  • (Integer)


27
# File 'lib/onlyfans/models/trial_link_create_params.rb', line 27

required :offer_expiration, Integer, api_name: :offerExpiration

#offer_limitInteger, Onlyfans::Models::TrialLinkCreateParams::OfferLimit

How many people can use this offer. Must either be 0 (for no limit), or a number between 1-10, 50, or 100.



34
# File 'lib/onlyfans/models/trial_link_create_params.rb', line 34

required :offer_limit, enum: -> { Onlyfans::TrialLinkCreateParams::OfferLimit }, api_name: :offerLimit

#tagsArray<String>?

Array of tag names to add to the trial link.

Returns:

  • (Array<String>, nil)


46
# File 'lib/onlyfans/models/trial_link_create_params.rb', line 46

optional :tags, Onlyfans::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Integer>

Returns:

  • (Array<Integer>)


# File 'lib/onlyfans/models/trial_link_create_params.rb', line 80