Class: Onlyfans::Models::TrialLinkListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::TrialLinkListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/trial_link_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #account ⇒ String
-
#field ⇒ Symbol, ...
Sort the results by a field.
-
#limit ⇒ Integer
The number of trial links to return.
-
#offset ⇒ Integer
The offset used for pagination.
-
#sort ⇒ Symbol, ...
Sort the results.
-
#synchronous ⇒ Boolean?
Wait for the revenue data to finish processing, instead of processing in the background.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account:, limit:, offset:, field: nil, sort: nil, synchronous: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TrialLinkListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, limit:, offset:, field: nil, sort: nil, synchronous: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Onlyfans::Models::TrialLinkListParams for more details.
|
|
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 47
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 13 required :account, String |
#field ⇒ Symbol, ...
Sort the results by a field. Default ‘create_date`
31 |
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 31 optional :field, enum: -> { Onlyfans::TrialLinkListParams::Field }, nil?: true |
#limit ⇒ Integer
The number of trial links to return. Default ‘10`
19 |
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 19 required :limit, Integer |
#offset ⇒ Integer
The offset used for pagination. Default ‘0`
25 |
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 25 required :offset, Integer |
#sort ⇒ Symbol, ...
Sort the results. Default ‘desc`
37 |
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 37 optional :sort, enum: -> { Onlyfans::TrialLinkListParams::Sort }, nil?: true |
#synchronous ⇒ Boolean?
Wait for the revenue data to finish processing, instead of processing in the background. **Will result in longer response times, use with caution**. Default ‘false`
45 |
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 45 optional :synchronous, Onlyfans::Internal::Type::Boolean, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/onlyfans/models/trial_link_list_params.rb', line 75
|