Class: Onlyfans::Models::UserListUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Onlyfans::Models::UserListUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onlyfans/models/user_list_update_params.rb
Overview
Instance Attribute Summary collapse
- #account ⇒ String
-
#is_pinned_to_feed ⇒ Boolean?
Whether to pin the User List to feed to the OnlyFans homepage or not.
-
#name ⇒ String
The new name for the User List.
- #user_list_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account:, user_list_id:, name:, is_pinned_to_feed: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account:, user_list_id:, name:, is_pinned_to_feed: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/onlyfans/models/user_list_update_params.rb', line 32
|
Instance Attribute Details
#account ⇒ String
13 |
# File 'lib/onlyfans/models/user_list_update_params.rb', line 13 required :account, String |
#is_pinned_to_feed ⇒ Boolean?
Whether to pin the User List to feed to the OnlyFans homepage or not.
30 |
# File 'lib/onlyfans/models/user_list_update_params.rb', line 30 optional :is_pinned_to_feed, Onlyfans::Internal::Type::Boolean, api_name: :isPinnedToFeed, nil?: true |
#name ⇒ String
The new name for the User List.
24 |
# File 'lib/onlyfans/models/user_list_update_params.rb', line 24 required :name, String |
#user_list_id ⇒ String
18 |
# File 'lib/onlyfans/models/user_list_update_params.rb', line 18 required :user_list_id, String |