Class: Onlyfans::Models::WebhookCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onlyfans/models/webhook_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_scope:, endpoint_url:, events:, account_ids: nil, signing_secret: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Onlyfans::Models::WebhookCreateParams for more details.

**List

Parameters:

  • account_scope (String)

    The account scope for the webhook. Use “global” for all accounts, “inclusive” fo

  • endpoint_url (String)

    The URL of your webhook endpoint.

  • events (Array<String>)

    An array of webhook events to subscribe to. For all options, refer to our

  • account_ids (Array<String>) (defaults to: nil)

    An array of account IDs to apply the scope to. Required unless account_scope is

  • signing_secret (String, nil) (defaults to: nil)

    Optionally, add a signing secret to protect your webhook.

  • request_options (Onlyfans::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onlyfans/models/webhook_create_params.rb', line 43

Instance Attribute Details

#account_idsArray<String>?

An array of account IDs to apply the scope to. Required unless account_scope is “global”.

Returns:

  • (Array<String>, nil)


35
# File 'lib/onlyfans/models/webhook_create_params.rb', line 35

optional :account_ids, Onlyfans::Internal::Type::ArrayOf[String]

#account_scopeString

The account scope for the webhook. Use “global” for all accounts, “inclusive” for only selected accounts, or “exclusive” for all except selected accounts.

Returns:

  • (String)


15
# File 'lib/onlyfans/models/webhook_create_params.rb', line 15

required :account_scope, String

#endpoint_urlString

The URL of your webhook endpoint.

Returns:

  • (String)


21
# File 'lib/onlyfans/models/webhook_create_params.rb', line 21

required :endpoint_url, String

#eventsArray<String>

An array of webhook events to subscribe to. For all options, refer to our **List Available Events** endpoint.

Returns:

  • (Array<String>)


28
# File 'lib/onlyfans/models/webhook_create_params.rb', line 28

required :events, Onlyfans::Internal::Type::ArrayOf[String]

#signing_secretString?

Optionally, add a signing secret to protect your webhook.

Returns:

  • (String, nil)


41
# File 'lib/onlyfans/models/webhook_create_params.rb', line 41

optional :signing_secret, String, nil?: true