Class: Onlyfans::Resources::Banking
- Inherits:
-
Object
- Object
- Onlyfans::Resources::Banking
- Defined in:
- lib/onlyfans/resources/banking.rb,
lib/onlyfans/resources/banking/details.rb
Overview
Operations related to user banking details, payout methods, legal and tax information, and account country settings.
Defined Under Namespace
Classes: Details
Instance Attribute Summary collapse
-
#details ⇒ Onlyfans::Resources::Banking::Details
readonly
Operations related to user banking details, payout methods, legal and tax information, and account country settings.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Banking
constructor
private
A new instance of Banking.
-
#list_available_payout_systems(account, request_options: {}) ⇒ Onlyfans::Models::BankingListAvailablePayoutSystemsResponse
Returns a list of available payout systems for the account, including details such as payout method codes, titles, descriptions, minimum payout amounts, processing times, and the currently selected payout method.
-
#list_countries(account, request_options: {}) ⇒ Onlyfans::Models::BankingListCountriesResponse
List countries, their internal OnlyFans IDs, and their payment & tax information.
Constructor Details
#initialize(client:) ⇒ Banking
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Banking.
59 60 61 62 |
# File 'lib/onlyfans/resources/banking.rb', line 59 def initialize(client:) @client = client @details = Onlyfans::Resources::Banking::Details.new(client: client) end |
Instance Attribute Details
#details ⇒ Onlyfans::Resources::Banking::Details (readonly)
Operations related to user banking details, payout methods, legal and tax information, and account country settings.
11 12 13 |
# File 'lib/onlyfans/resources/banking.rb', line 11 def details @details end |
Instance Method Details
#list_available_payout_systems(account, request_options: {}) ⇒ Onlyfans::Models::BankingListAvailablePayoutSystemsResponse
Returns a list of available payout systems for the account, including details such as payout method codes, titles, descriptions, minimum payout amounts, processing times, and the currently selected payout method.
26 27 28 29 30 31 32 33 |
# File 'lib/onlyfans/resources/banking.rb', line 26 def list_available_payout_systems(account, params = {}) @client.request( method: :get, path: ["api/%1$s/banking/available-payout-systems", account], model: Onlyfans::Models::BankingListAvailablePayoutSystemsResponse, options: params[:request_options] ) end |
#list_countries(account, request_options: {}) ⇒ Onlyfans::Models::BankingListCountriesResponse
List countries, their internal OnlyFans IDs, and their payment & tax information.
47 48 49 50 51 52 53 54 |
# File 'lib/onlyfans/resources/banking.rb', line 47 def list_countries(account, params = {}) @client.request( method: :get, path: ["api/%1$s/banking/countries", account], model: Onlyfans::Models::BankingListCountriesResponse, options: params[:request_options] ) end |