Class: Onlyfans::Resources::Stored
- Inherits:
-
Object
- Object
- Onlyfans::Resources::Stored
- Defined in:
- lib/onlyfans/resources/stored.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Stored
constructor
private
A new instance of Stored.
-
#list_shared_tracking_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListSharedTrackingLinksResponse
Some parameter documentations has been truncated, see Models::StoredListSharedTrackingLinksParams for more details.
-
#list_shared_trial_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListSharedTrialLinksResponse
Some parameter documentations has been truncated, see Models::StoredListSharedTrialLinksParams for more details.
-
#list_tracking_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListTrackingLinksResponse
Some parameter documentations has been truncated, see Models::StoredListTrackingLinksParams for more details.
-
#list_trial_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListTrialLinksResponse
Some parameter documentations has been truncated, see Models::StoredListTrialLinksParams for more details.
Constructor Details
#initialize(client:) ⇒ Stored
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Stored.
141 142 143 |
# File 'lib/onlyfans/resources/stored.rb', line 141 def initialize(client:) @client = client end |
Instance Method Details
#list_shared_tracking_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListSharedTrackingLinksResponse
Some parameter documentations has been truncated, see Models::StoredListSharedTrackingLinksParams for more details.
List all shared Tracking Links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.
27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/onlyfans/resources/stored.rb', line 27 def list_shared_tracking_links(account, params = {}) parsed, = Onlyfans::StoredListSharedTrackingLinksParams.dump_request(params) query = Onlyfans::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["api/%1$s/stored/shared-tracking-links", account], query: query, model: Onlyfans::Models::StoredListSharedTrackingLinksResponse, options: ) end |
#list_shared_trial_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListSharedTrialLinksResponse
Some parameter documentations has been truncated, see Models::StoredListSharedTrialLinksParams for more details.
List all shared Free Trial Links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/onlyfans/resources/stored.rb', line 60 def list_shared_trial_links(account, params = {}) parsed, = Onlyfans::StoredListSharedTrialLinksParams.dump_request(params) query = Onlyfans::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["api/%1$s/stored/shared-trial-links", account], query: query, model: Onlyfans::Models::StoredListSharedTrialLinksResponse, options: ) end |
#list_tracking_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListTrackingLinksResponse
Some parameter documentations has been truncated, see Models::StoredListTrackingLinksParams for more details.
List all stored tracking links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.
93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/onlyfans/resources/stored.rb', line 93 def list_tracking_links(account, params = {}) parsed, = Onlyfans::StoredListTrackingLinksParams.dump_request(params) query = Onlyfans::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["api/%1$s/stored/tracking-links", account], query: query, model: Onlyfans::Models::StoredListTrackingLinksResponse, options: ) end |
#list_trial_links(account, filter: nil, limit: nil, offset: nil, request_options: {}) ⇒ Onlyfans::Models::StoredListTrialLinksResponse
Some parameter documentations has been truncated, see Models::StoredListTrialLinksParams for more details.
List all stored free trial links from the OnlyFansAPI Cache. This is a free endpoint that does not call the OnlyFans API.
126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/onlyfans/resources/stored.rb', line 126 def list_trial_links(account, params = {}) parsed, = Onlyfans::StoredListTrialLinksParams.dump_request(params) query = Onlyfans::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["api/%1$s/stored/trial-links", account], query: query, model: Onlyfans::Models::StoredListTrialLinksResponse, options: ) end |